package androidx.test.internal.runner.lifecycle;

import android.app.Activity;
import android.os.Looper;
import android.util.Log;
import androidx.test.internal.util.Checks;
import androidx.test.runner.lifecycle.ActivityLifecycleCallback;
import androidx.test.runner.lifecycle.ActivityLifecycleMonitor;
import androidx.test.runner.lifecycle.Stage;
import java.lang.ref.WeakReference;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

public final class ActivityLifecycleMonitorImpl implements ActivityLifecycleMonitor {
    private static final String TAG = "LifecycleMonitor";
    private List<ActivityStatus> activityStatuses;
    private final List<WeakReference<ActivityLifecycleCallback>> callbacks;
    private final boolean declawThreadCheck;

    public ActivityLifecycleMonitorImpl() {
        this(false);
    }

    public ActivityLifecycleMonitorImpl(boolean declawThreadCheck2) {
        this.callbacks = new ArrayList();
        this.activityStatuses = new ArrayList();
        this.declawThreadCheck = declawThreadCheck2;
    }

    public void addLifecycleCallback(ActivityLifecycleCallback callback) {
        Checks.checkNotNull(callback);
        synchronized (this.callbacks) {
            boolean needsAdd = true;
            Iterator<WeakReference<ActivityLifecycleCallback>> refIter = this.callbacks.iterator();
            while (refIter.hasNext()) {
                ActivityLifecycleCallback storedCallback = (ActivityLifecycleCallback) refIter.next().get();
                if (storedCallback == null) {
                    refIter.remove();
                } else if (storedCallback == callback) {
                    needsAdd = false;
                }
            }
            if (needsAdd) {
                this.callbacks.add(new WeakReference(callback));
            }
        }
    }

    public void removeLifecycleCallback(ActivityLifecycleCallback callback) {
        Checks.checkNotNull(callback);
        synchronized (this.callbacks) {
            Iterator<WeakReference<ActivityLifecycleCallback>> refIter = this.callbacks.iterator();
            while (refIter.hasNext()) {
                ActivityLifecycleCallback storedCallback = (ActivityLifecycleCallback) refIter.next().get();
                if (storedCallback == null) {
                    refIter.remove();
                } else if (storedCallback == callback) {
                    refIter.remove();
                }
            }
        }
    }

    public Stage getLifecycleStageOf(Activity activity) {
        checkMainThread();
        Checks.checkNotNull(activity);
        Iterator<ActivityStatus> statusIterator = this.activityStatuses.iterator();
        while (statusIterator.hasNext()) {
            ActivityStatus status = statusIterator.next();
            Activity statusActivity = (Activity) status.activityRef.get();
            if (statusActivity == null) {
                statusIterator.remove();
            } else if (activity == statusActivity) {
                return status.lifecycleStage;
            }
        }
        String valueOf = String.valueOf(activity);
        StringBuilder sb = new StringBuilder(String.valueOf(valueOf).length() + 18);
        sb.append("Unknown activity: ");
        sb.append(valueOf);
        throw new IllegalArgumentException(sb.toString());
    }

    public Collection<Activity> getActivitiesInStage(Stage stage) {
        checkMainThread();
        Checks.checkNotNull(stage);
        List<Activity> activities = new ArrayList<>();
        Iterator<ActivityStatus> statusIterator = this.activityStatuses.iterator();
        while (statusIterator.hasNext()) {
            ActivityStatus status = statusIterator.next();
            Activity statusActivity = (Activity) status.activityRef.get();
            if (statusActivity == null) {
                statusIterator.remove();
            } else if (stage == status.lifecycleStage) {
                activities.add(statusActivity);
            }
        }
        return activities;
    }

    public void signalLifecycleChange(Stage stage, Activity activity) {
        String valueOf = String.valueOf(activity);
        String valueOf2 = String.valueOf(stage);
        StringBuilder sb = new StringBuilder(String.valueOf(valueOf).length() + 30 + String.valueOf(valueOf2).length());
        sb.append("Lifecycle status change: ");
        sb.append(valueOf);
        sb.append(" in: ");
        sb.append(valueOf2);
        Log.d(TAG, sb.toString());
        boolean needsAdd = true;
        Iterator<ActivityStatus> statusIterator = this.activityStatuses.iterator();
        while (statusIterator.hasNext()) {
            ActivityStatus status = statusIterator.next();
            Activity statusActivity = (Activity) status.activityRef.get();
            if (statusActivity == null) {
                statusIterator.remove();
            } else if (activity == statusActivity) {
                needsAdd = false;
                Stage unused = status.lifecycleStage = stage;
            }
        }
        if (needsAdd) {
            this.activityStatuses.add(new ActivityStatus(activity, stage));
        }
        synchronized (this.callbacks) {
            Iterator<WeakReference<ActivityLifecycleCallback>> refIter = this.callbacks.iterator();
            while (refIter.hasNext()) {
                ActivityLifecycleCallback callback = (ActivityLifecycleCallback) refIter.next().get();
                if (callback == null) {
                    refIter.remove();
                } else {
                    try {
                        callback.onActivityLifecycleChanged(activity, stage);
                    } catch (RuntimeException re) {
                        Log.e(TAG, String.format("Callback threw exception! (callback: %s activity: %s stage: %s)", new Object[]{callback, activity, stage}), re);
                    }
                }
            }
        }
    }

    private void checkMainThread() {
        if (!this.declawThreadCheck && !Thread.currentThread().equals(Looper.getMainLooper().getThread())) {
            throw new IllegalStateException("Querying activity state off main thread is not allowed.");
        }
    }

    private static class ActivityStatus {
        /* access modifiers changed from: private */
        public final WeakReference<Activity> activityRef;
        /* access modifiers changed from: private */
        public Stage lifecycleStage;

        ActivityStatus(Activity activity, Stage stage) {
            this.activityRef = new WeakReference<>((Activity) Checks.checkNotNull(activity));
            this.lifecycleStage = (Stage) Checks.checkNotNull(stage);
        }
    }
}
