package org.commonmark.internal;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.Reader;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;
import org.commonmark.internal.BlockQuoteParser;
import org.commonmark.internal.FencedCodeBlockParser;
import org.commonmark.internal.HeadingParser;
import org.commonmark.internal.HtmlBlockParser;
import org.commonmark.internal.IndentedCodeBlockParser;
import org.commonmark.internal.ListBlockParser;
import org.commonmark.internal.ThematicBreakParser;
import org.commonmark.internal.util.Parsing;
import org.commonmark.node.Block;
import org.commonmark.node.BlockQuote;
import org.commonmark.node.Document;
import org.commonmark.node.FencedCodeBlock;
import org.commonmark.node.Heading;
import org.commonmark.node.HtmlBlock;
import org.commonmark.node.IndentedCodeBlock;
import org.commonmark.node.ListBlock;
import org.commonmark.node.Paragraph;
import org.commonmark.node.ThematicBreak;
import org.commonmark.parser.InlineParser;
import org.commonmark.parser.block.BlockContinue;
import org.commonmark.parser.block.BlockParser;
import org.commonmark.parser.block.BlockParserFactory;
import org.commonmark.parser.block.BlockStart;
import org.commonmark.parser.block.MatchedBlockParser;
import org.commonmark.parser.block.ParserState;

public class DocumentParser implements ParserState {
    private static final Set<Class<? extends Block>> CORE_FACTORY_TYPES = new LinkedHashSet(Arrays.asList(new Class[]{BlockQuote.class, Heading.class, FencedCodeBlock.class, HtmlBlock.class, ThematicBreak.class, ListBlock.class, IndentedCodeBlock.class}));
    private static final Map<Class<? extends Block>, BlockParserFactory> NODES_TO_CORE_FACTORIES;
    private List<BlockParser> activeBlockParsers = new ArrayList();
    private Set<BlockParser> allBlockParsers = new HashSet();
    private boolean blank;
    private final List<BlockParserFactory> blockParserFactories;
    private int column = 0;
    private boolean columnIsInTab;
    private final DocumentBlockParser documentBlockParser;
    private int indent = 0;
    private int index = 0;
    private final InlineParser inlineParser;
    private CharSequence line;
    private int nextNonSpace = 0;
    private int nextNonSpaceColumn = 0;

    static {
        Map<Class<? extends Block>, BlockParserFactory> map = new HashMap<>();
        map.put(BlockQuote.class, new BlockQuoteParser.Factory());
        map.put(Heading.class, new HeadingParser.Factory());
        map.put(FencedCodeBlock.class, new FencedCodeBlockParser.Factory());
        map.put(HtmlBlock.class, new HtmlBlockParser.Factory());
        map.put(ThematicBreak.class, new ThematicBreakParser.Factory());
        map.put(ListBlock.class, new ListBlockParser.Factory());
        map.put(IndentedCodeBlock.class, new IndentedCodeBlockParser.Factory());
        NODES_TO_CORE_FACTORIES = Collections.unmodifiableMap(map);
    }

    public DocumentParser(List<BlockParserFactory> blockParserFactories2, InlineParser inlineParser2) {
        this.blockParserFactories = blockParserFactories2;
        this.inlineParser = inlineParser2;
        DocumentBlockParser documentBlockParser2 = new DocumentBlockParser();
        this.documentBlockParser = documentBlockParser2;
        activateBlockParser(documentBlockParser2);
    }

    public static Set<Class<? extends Block>> getDefaultBlockParserTypes() {
        return CORE_FACTORY_TYPES;
    }

    public static List<BlockParserFactory> calculateBlockParserFactories(List<BlockParserFactory> customBlockParserFactories, Set<Class<? extends Block>> enabledBlockTypes) {
        List<BlockParserFactory> list = new ArrayList<>();
        list.addAll(customBlockParserFactories);
        for (Class<? extends Block> blockType : enabledBlockTypes) {
            list.add(NODES_TO_CORE_FACTORIES.get(blockType));
        }
        return list;
    }

    public Document parse(String input) {
        int lineStart = 0;
        while (true) {
            int findLineBreak = Parsing.findLineBreak(input, lineStart);
            int lineBreak = findLineBreak;
            if (findLineBreak == -1) {
                break;
            }
            incorporateLine(input.substring(lineStart, lineBreak));
            if (lineBreak + 1 < input.length() && input.charAt(lineBreak) == 13 && input.charAt(lineBreak + 1) == 10) {
                lineStart = lineBreak + 2;
            } else {
                lineStart = lineBreak + 1;
            }
        }
        if (input.length() > 0 && (lineStart == 0 || lineStart < input.length())) {
            incorporateLine(input.substring(lineStart));
        }
        return finalizeAndProcess();
    }

    public Document parse(Reader input) throws IOException {
        BufferedReader bufferedReader;
        if (input instanceof BufferedReader) {
            bufferedReader = (BufferedReader) input;
        } else {
            bufferedReader = new BufferedReader(input);
        }
        while (true) {
            String readLine = bufferedReader.readLine();
            String line2 = readLine;
            if (readLine == null) {
                return finalizeAndProcess();
            }
            incorporateLine(line2);
        }
    }

    public CharSequence getLine() {
        return this.line;
    }

    public int getIndex() {
        return this.index;
    }

    public int getNextNonSpaceIndex() {
        return this.nextNonSpace;
    }

    public int getColumn() {
        return this.column;
    }

    public int getIndent() {
        return this.indent;
    }

    public boolean isBlank() {
        return this.blank;
    }

    public BlockParser getActiveBlockParser() {
        List<BlockParser> list = this.activeBlockParsers;
        return list.get(list.size() - 1);
    }

    private void incorporateLine(CharSequence ln) {
        this.line = Parsing.prepareLine(ln);
        this.index = 0;
        this.column = 0;
        this.columnIsInTab = false;
        int matches = 1;
        List<BlockParser> list = this.activeBlockParsers;
        boolean tryBlockStarts = true;
        for (BlockParser blockParser : list.subList(1, list.size())) {
            findNextNonSpace();
            BlockContinue result = blockParser.tryContinue(this);
            if (!(result instanceof BlockContinueImpl)) {
                break;
            }
            BlockContinueImpl blockContinue = (BlockContinueImpl) result;
            if (blockContinue.isFinalize()) {
                finalize(blockParser);
                return;
            }
            if (blockContinue.getNewIndex() != -1) {
                setNewIndex(blockContinue.getNewIndex());
            } else if (blockContinue.getNewColumn() != -1) {
                setNewColumn(blockContinue.getNewColumn());
            }
            matches++;
        }
        List<BlockParser> list2 = this.activeBlockParsers;
        List<BlockParser> unmatchedBlockParsers = new ArrayList<>(list2.subList(matches, list2.size()));
        BlockParser blockParser2 = this.activeBlockParsers.get(matches - 1);
        boolean allClosed = unmatchedBlockParsers.isEmpty();
        if (!(blockParser2.getBlock() instanceof Paragraph) && !blockParser2.isContainer()) {
            tryBlockStarts = false;
        }
        while (true) {
            if (!tryBlockStarts) {
                break;
            }
            findNextNonSpace();
            if (isBlank() || (this.indent < Parsing.CODE_BLOCK_INDENT && Parsing.isLetter(this.line, this.nextNonSpace))) {
                setNewIndex(this.nextNonSpace);
            } else {
                BlockStartImpl blockStart = findBlockStart(blockParser2);
                if (blockStart == null) {
                    setNewIndex(this.nextNonSpace);
                    break;
                }
                if (!allClosed) {
                    finalizeBlocks(unmatchedBlockParsers);
                    allClosed = true;
                }
                if (blockStart.getNewIndex() != -1) {
                    setNewIndex(blockStart.getNewIndex());
                } else if (blockStart.getNewColumn() != -1) {
                    setNewColumn(blockStart.getNewColumn());
                }
                if (blockStart.isReplaceActiveBlockParser()) {
                    removeActiveBlockParser();
                }
                for (BlockParser newBlockParser : blockStart.getBlockParsers()) {
                    blockParser2 = addChild(newBlockParser);
                    tryBlockStarts = newBlockParser.isContainer();
                }
            }
        }
        if (allClosed || isBlank() || !(getActiveBlockParser() instanceof ParagraphParser)) {
            if (!allClosed) {
                finalizeBlocks(unmatchedBlockParsers);
            }
            if (!blockParser2.isContainer()) {
                addLine();
            } else if (!isBlank()) {
                addChild(new ParagraphParser());
                addLine();
            }
        } else {
            addLine();
        }
    }

    private void findNextNonSpace() {
        int i = this.index;
        int cols = this.column;
        this.blank = true;
        int length = this.line.length();
        while (true) {
            if (i < length) {
                switch (this.line.charAt(i)) {
                    case 9:
                        i++;
                        cols += 4 - (cols % 4);
                        continue;
                    case ' ':
                        i++;
                        cols++;
                        continue;
                    default:
                        this.blank = false;
                        break;
                }
            }
        }
        this.nextNonSpace = i;
        this.nextNonSpaceColumn = cols;
        this.indent = cols - this.column;
    }

    private void setNewIndex(int newIndex) {
        int i = this.nextNonSpace;
        if (newIndex >= i) {
            this.index = i;
            this.column = this.nextNonSpaceColumn;
        }
        int length = this.line.length();
        while (true) {
            int i2 = this.index;
            if (i2 >= newIndex || i2 == length) {
                this.columnIsInTab = false;
            } else {
                advance();
            }
        }
        this.columnIsInTab = false;
    }

    /* JADX WARNING: Removed duplicated region for block: B:10:0x001e  */
    /* JADX WARNING: Removed duplicated region for block: B:11:0x0029  */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    private void setNewColumn(int r4) {
        /*
            r3 = this;
            int r0 = r3.nextNonSpaceColumn
            if (r4 < r0) goto L_0x000a
            int r1 = r3.nextNonSpace
            r3.index = r1
            r3.column = r0
        L_0x000a:
            java.lang.CharSequence r0 = r3.line
            int r0 = r0.length()
        L_0x0010:
            int r1 = r3.column
            if (r1 >= r4) goto L_0x001c
            int r2 = r3.index
            if (r2 == r0) goto L_0x001c
            r3.advance()
            goto L_0x0010
        L_0x001c:
            if (r1 <= r4) goto L_0x0029
            int r1 = r3.index
            r2 = 1
            int r1 = r1 - r2
            r3.index = r1
            r3.column = r4
            r3.columnIsInTab = r2
            goto L_0x002c
        L_0x0029:
            r1 = 0
            r3.columnIsInTab = r1
        L_0x002c:
            return
        */
        throw new UnsupportedOperationException("Method not decompiled: org.commonmark.internal.DocumentParser.setNewColumn(int):void");
    }

    private void advance() {
        if (this.line.charAt(this.index) == 9) {
            this.index++;
            int i = this.column;
            this.column = i + Parsing.columnsToNextTabStop(i);
            return;
        }
        this.index++;
        this.column++;
    }

    private void addLine() {
        CharSequence content;
        if (this.columnIsInTab) {
            CharSequence charSequence = this.line;
            CharSequence rest = charSequence.subSequence(this.index + 1, charSequence.length());
            int spaces = Parsing.columnsToNextTabStop(this.column);
            StringBuilder sb = new StringBuilder(rest.length() + spaces);
            for (int i = 0; i < spaces; i++) {
                sb.append(' ');
            }
            sb.append(rest);
            content = sb.toString();
        } else {
            CharSequence content2 = this.line;
            content = content2.subSequence(this.index, content2.length());
        }
        getActiveBlockParser().addLine(content);
    }

    private BlockStartImpl findBlockStart(BlockParser blockParser) {
        MatchedBlockParser matchedBlockParser = new MatchedBlockParserImpl(blockParser);
        for (BlockParserFactory blockParserFactory : this.blockParserFactories) {
            BlockStart result = blockParserFactory.tryStart(this, matchedBlockParser);
            if (result instanceof BlockStartImpl) {
                return (BlockStartImpl) result;
            }
        }
        return null;
    }

    private void finalize(BlockParser blockParser) {
        if (getActiveBlockParser() == blockParser) {
            deactivateBlockParser();
        }
        blockParser.closeBlock();
        if (blockParser instanceof ParagraphParser) {
            InlineParser inlineParser2 = this.inlineParser;
            if (inlineParser2 instanceof ReferenceParser) {
                ((ParagraphParser) blockParser).closeBlock((ReferenceParser) inlineParser2);
            }
        }
    }

    private void processInlines() {
        for (BlockParser blockParser : this.allBlockParsers) {
            blockParser.parseInlines(this.inlineParser);
        }
    }

    private <T extends BlockParser> T addChild(T blockParser) {
        while (!getActiveBlockParser().canContain(blockParser.getBlock())) {
            finalize(getActiveBlockParser());
        }
        getActiveBlockParser().getBlock().appendChild(blockParser.getBlock());
        activateBlockParser(blockParser);
        return blockParser;
    }

    private void activateBlockParser(BlockParser blockParser) {
        this.activeBlockParsers.add(blockParser);
        this.allBlockParsers.add(blockParser);
    }

    private void deactivateBlockParser() {
        List<BlockParser> list = this.activeBlockParsers;
        list.remove(list.size() - 1);
    }

    private void removeActiveBlockParser() {
        BlockParser old = getActiveBlockParser();
        deactivateBlockParser();
        this.allBlockParsers.remove(old);
        old.getBlock().unlink();
    }

    private void finalizeBlocks(List<BlockParser> blockParsers) {
        for (int i = blockParsers.size() - 1; i >= 0; i--) {
            finalize(blockParsers.get(i));
        }
    }

    private Document finalizeAndProcess() {
        finalizeBlocks(this.activeBlockParsers);
        processInlines();
        return this.documentBlockParser.getBlock();
    }

    private static class MatchedBlockParserImpl implements MatchedBlockParser {
        private final BlockParser matchedBlockParser;

        public MatchedBlockParserImpl(BlockParser matchedBlockParser2) {
            this.matchedBlockParser = matchedBlockParser2;
        }

        public BlockParser getMatchedBlockParser() {
            return this.matchedBlockParser;
        }

        public CharSequence getParagraphContent() {
            BlockParser blockParser = this.matchedBlockParser;
            if (blockParser instanceof ParagraphParser) {
                return ((ParagraphParser) blockParser).getContentString();
            }
            return null;
        }
    }
}
