package org.commonmark.internal;

import androidx.core.net.MailTo;
import java.util.Arrays;
import java.util.BitSet;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import org.commonmark.internal.inline.AsteriskDelimiterProcessor;
import org.commonmark.internal.inline.UnderscoreDelimiterProcessor;
import org.commonmark.internal.util.Escaping;
import org.commonmark.internal.util.Html5Entities;
import org.commonmark.node.Code;
import org.commonmark.node.HardLineBreak;
import org.commonmark.node.HtmlInline;
import org.commonmark.node.Image;
import org.commonmark.node.Link;
import org.commonmark.node.Node;
import org.commonmark.node.SoftLineBreak;
import org.commonmark.node.Text;
import org.commonmark.parser.InlineParser;
import org.commonmark.parser.delimiter.DelimiterProcessor;

public class InlineParserImpl implements InlineParser, ReferenceParser {
    private static final String ASCII_PUNCTUATION = "!\"#\\$%&'\\(\\)\\*\\+,\\-\\./:;<=>\\?@\\[\\\\\\]\\^_`\\{\\|\\}~";
    private static final Pattern AUTOLINK = Pattern.compile("^<[a-zA-Z][a-zA-Z0-9.+-]{1,31}:[^<>\u0000- ]*>");
    private static final String CDATA = "<!\\[CDATA\\[[\\s\\S]*?\\]\\]>";
    private static final String DECLARATION = "<![A-Z]+\\s+[^>]*>";
    private static final Pattern EMAIL_AUTOLINK = Pattern.compile("^<([a-zA-Z0-9.!#$%&'*+/=?^_`{|}~-]+@[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)*)>");
    private static final String ENTITY = "&(?:#x[a-f0-9]{1,8}|#[0-9]{1,8}|[a-z][a-z0-9]{1,31});";
    private static final Pattern ENTITY_HERE = Pattern.compile("^&(?:#x[a-f0-9]{1,8}|#[0-9]{1,8}|[a-z][a-z0-9]{1,31});", 2);
    private static final Pattern ESCAPABLE = Pattern.compile("^[!\"#$%&'()*+,./:;<=>?@\\[\\\\\\]^_`{|}~-]");
    private static final String ESCAPED_CHAR = "\\\\[!\"#$%&'()*+,./:;<=>?@\\[\\\\\\]^_`{|}~-]";
    private static final Pattern FINAL_SPACE = Pattern.compile(" *$");
    private static final String HTMLCOMMENT = "<!---->|<!--(?:-?[^>-])(?:-?[^-])*-->";
    private static final String HTMLTAG = "(?:<[A-Za-z][A-Za-z0-9-]*(?:\\s+[a-zA-Z_:][a-zA-Z0-9:._-]*(?:\\s*=\\s*(?:[^\"'=<>`\\x00-\\x20]+|'[^']*'|\"[^\"]*\"))?)*\\s*/?>|</[A-Za-z][A-Za-z0-9-]*\\s*[>]|<!---->|<!--(?:-?[^>-])(?:-?[^-])*-->|[<][?].*?[?][>]|<![A-Z]+\\s+[^>]*>|<!\\[CDATA\\[[\\s\\S]*?\\]\\]>)";
    private static final Pattern HTML_TAG = Pattern.compile("^(?:<[A-Za-z][A-Za-z0-9-]*(?:\\s+[a-zA-Z_:][a-zA-Z0-9:._-]*(?:\\s*=\\s*(?:[^\"'=<>`\\x00-\\x20]+|'[^']*'|\"[^\"]*\"))?)*\\s*/?>|</[A-Za-z][A-Za-z0-9-]*\\s*[>]|<!---->|<!--(?:-?[^>-])(?:-?[^-])*-->|[<][?].*?[?][>]|<![A-Z]+\\s+[^>]*>|<!\\[CDATA\\[[\\s\\S]*?\\]\\]>)", 2);
    private static final Pattern LINE_END = Pattern.compile("^ *(?:\n|$)");
    private static final Pattern LINK_DESTINATION_BRACES = Pattern.compile("^(?:[<](?:[^<> \\t\\n\\\\]|\\\\.)*[>])");
    private static final Pattern LINK_LABEL = Pattern.compile("^\\[(?:[^\\\\\\[\\]]|\\\\.)*\\]");
    private static final Pattern LINK_TITLE = Pattern.compile("^(?:\"(\\\\[!\"#$%&'()*+,./:;<=>?@\\[\\\\\\]^_`{|}~-]|[^\"\\x00])*\"|'(\\\\[!\"#$%&'()*+,./:;<=>?@\\[\\\\\\]^_`{|}~-]|[^'\\x00])*'|\\((\\\\[!\"#$%&'()*+,./:;<=>?@\\[\\\\\\]^_`{|}~-]|[^)\\x00])*\\))");
    private static final String PROCESSINGINSTRUCTION = "[<][?].*?[?][>]";
    private static final Pattern PUNCTUATION = Pattern.compile("^[!\"#\\$%&'\\(\\)\\*\\+,\\-\\./:;<=>\\?@\\[\\\\\\]\\^_`\\{\\|\\}~\\p{Pc}\\p{Pd}\\p{Pe}\\p{Pf}\\p{Pi}\\p{Po}\\p{Ps}]");
    private static final Pattern SPNL = Pattern.compile("^ *(?:\n *)?");
    private static final Pattern TICKS = Pattern.compile("`+");
    private static final Pattern TICKS_HERE = Pattern.compile("^`+");
    private static final Pattern UNICODE_WHITESPACE_CHAR = Pattern.compile("^[\\p{Zs}\t\r\n\f]");
    private static final Pattern WHITESPACE = Pattern.compile("\\s+");
    private Node block;
    private final BitSet delimiterCharacters;
    private final Map<Character, DelimiterProcessor> delimiterProcessors;
    private int index;
    private String input;
    private Bracket lastBracket;
    private Delimiter lastDelimiter;
    private Map<String, Link> referenceMap = new HashMap();
    private final BitSet specialCharacters;

    public InlineParserImpl(List<DelimiterProcessor> delimiterProcessors2) {
        Map<Character, DelimiterProcessor> calculateDelimiterProcessors = calculateDelimiterProcessors(delimiterProcessors2);
        this.delimiterProcessors = calculateDelimiterProcessors;
        BitSet calculateDelimiterCharacters = calculateDelimiterCharacters(calculateDelimiterProcessors.keySet());
        this.delimiterCharacters = calculateDelimiterCharacters;
        this.specialCharacters = calculateSpecialCharacters(calculateDelimiterCharacters);
    }

    public static BitSet calculateDelimiterCharacters(Set<Character> characters) {
        BitSet bitSet = new BitSet();
        for (Character character : characters) {
            bitSet.set(character.charValue());
        }
        return bitSet;
    }

    public static BitSet calculateSpecialCharacters(BitSet delimiterCharacters2) {
        BitSet bitSet = new BitSet();
        bitSet.or(delimiterCharacters2);
        bitSet.set(10);
        bitSet.set(96);
        bitSet.set(91);
        bitSet.set(93);
        bitSet.set(92);
        bitSet.set(33);
        bitSet.set(60);
        bitSet.set(38);
        return bitSet;
    }

    public static Map<Character, DelimiterProcessor> calculateDelimiterProcessors(List<DelimiterProcessor> delimiterProcessors2) {
        Map<Character, DelimiterProcessor> map = new HashMap<>();
        addDelimiterProcessors(Arrays.asList(new DelimiterProcessor[]{new AsteriskDelimiterProcessor(), new UnderscoreDelimiterProcessor()}), map);
        addDelimiterProcessors(delimiterProcessors2, map);
        return map;
    }

    private static void addDelimiterProcessors(Iterable<DelimiterProcessor> delimiterProcessors2, Map<Character, DelimiterProcessor> map) {
        StaggeredDelimiterProcessor s;
        for (DelimiterProcessor delimiterProcessor : delimiterProcessors2) {
            char opening = delimiterProcessor.getOpeningCharacter();
            char closing = delimiterProcessor.getClosingCharacter();
            if (opening == closing) {
                DelimiterProcessor old = map.get(Character.valueOf(opening));
                if (old == null || old.getOpeningCharacter() != old.getClosingCharacter()) {
                    addDelimiterProcessorForChar(opening, delimiterProcessor, map);
                } else {
                    if (old instanceof StaggeredDelimiterProcessor) {
                        s = (StaggeredDelimiterProcessor) old;
                    } else {
                        s = new StaggeredDelimiterProcessor(opening);
                        s.add(old);
                    }
                    s.add(delimiterProcessor);
                    map.put(Character.valueOf(opening), s);
                }
            } else {
                addDelimiterProcessorForChar(opening, delimiterProcessor, map);
                addDelimiterProcessorForChar(closing, delimiterProcessor, map);
            }
        }
    }

    private static void addDelimiterProcessorForChar(char delimiterChar, DelimiterProcessor toAdd, Map<Character, DelimiterProcessor> delimiterProcessors2) {
        if (delimiterProcessors2.put(Character.valueOf(delimiterChar), toAdd) != null) {
            throw new IllegalArgumentException("Delimiter processor conflict with delimiter char '" + delimiterChar + "'");
        }
    }

    public void parse(String content, Node block2) {
        this.block = block2;
        this.input = content.trim();
        this.index = 0;
        this.lastDelimiter = null;
        this.lastBracket = null;
        do {
        } while (parseInline());
        processDelimiters((Delimiter) null);
        mergeChildTextNodes(block2);
    }

    public int parseReference(String s) {
        this.input = s;
        this.index = 0;
        int startIndex = this.index;
        int matchChars = parseLinkLabel();
        if (matchChars == 0) {
            return 0;
        }
        String rawLabel = this.input.substring(0, matchChars);
        if (peek() != ':') {
            return 0;
        }
        boolean z = true;
        this.index++;
        spnl();
        String dest = parseLinkDestination();
        if (dest == null || dest.length() == 0) {
            return 0;
        }
        int beforeTitle = this.index;
        spnl();
        String title = parseLinkTitle();
        if (title == null) {
            this.index = beforeTitle;
        }
        boolean atLineEnd = true;
        if (this.index != this.input.length()) {
            Pattern pattern = LINE_END;
            if (match(pattern) == null) {
                if (title == null) {
                    atLineEnd = false;
                } else {
                    title = null;
                    this.index = beforeTitle;
                    if (match(pattern) == null) {
                        z = false;
                    }
                    atLineEnd = z;
                }
            }
        }
        if (!atLineEnd) {
            return 0;
        }
        String normalizedLabel = Escaping.normalizeReference(rawLabel);
        if (normalizedLabel.isEmpty()) {
            return 0;
        }
        if (!this.referenceMap.containsKey(normalizedLabel)) {
            this.referenceMap.put(normalizedLabel, new Link(dest, title));
        }
        return this.index - startIndex;
    }

    private Text appendText(CharSequence text, int beginIndex, int endIndex) {
        return appendText(text.subSequence(beginIndex, endIndex));
    }

    private Text appendText(CharSequence text) {
        Text node = new Text(text.toString());
        appendNode(node);
        return node;
    }

    private void appendNode(Node node) {
        this.block.appendChild(node);
    }

    private boolean parseInline() {
        char c = peek();
        boolean isDelimiter = false;
        if (c == 0) {
            return false;
        }
        switch (c) {
            case 10:
                isDelimiter = parseNewline();
                break;
            case '!':
                isDelimiter = parseBang();
                break;
            case '&':
                isDelimiter = parseEntity();
                break;
            case '<':
                if (parseAutolink() || parseHtmlInline()) {
                    isDelimiter = true;
                    break;
                }
            case '[':
                isDelimiter = parseOpenBracket();
                break;
            case '\\':
                isDelimiter = parseBackslash();
                break;
            case ']':
                isDelimiter = parseCloseBracket();
                break;
            case '`':
                isDelimiter = parseBackticks();
                break;
            default:
                if (!this.delimiterCharacters.get(c)) {
                    isDelimiter = parseString();
                    break;
                } else {
                    isDelimiter = parseDelimiters(this.delimiterProcessors.get(Character.valueOf(c)), c);
                    break;
                }
        }
        if (!isDelimiter) {
            this.index++;
            appendText(String.valueOf(c));
        }
        return true;
    }

    private String match(Pattern re) {
        if (this.index >= this.input.length()) {
            return null;
        }
        Matcher matcher = re.matcher(this.input);
        matcher.region(this.index, this.input.length());
        if (!matcher.find()) {
            return null;
        }
        this.index = matcher.end();
        return matcher.group();
    }

    private char peek() {
        if (this.index < this.input.length()) {
            return this.input.charAt(this.index);
        }
        return 0;
    }

    private boolean spnl() {
        match(SPNL);
        return true;
    }

    private boolean parseNewline() {
        this.index++;
        Node lastChild = this.block.getLastChild();
        if (lastChild == null || !(lastChild instanceof Text) || !((Text) lastChild).getLiteral().endsWith(" ")) {
            appendNode(new SoftLineBreak());
        } else {
            Text text = (Text) lastChild;
            String literal = text.getLiteral();
            Matcher matcher = FINAL_SPACE.matcher(literal);
            int spaces = matcher.find() ? matcher.end() - matcher.start() : 0;
            if (spaces > 0) {
                text.setLiteral(literal.substring(0, literal.length() - spaces));
            }
            appendNode(spaces >= 2 ? new HardLineBreak() : new SoftLineBreak());
        }
        while (peek() == ' ') {
            this.index++;
        }
        return true;
    }

    private boolean parseBackslash() {
        this.index++;
        if (peek() == 10) {
            appendNode(new HardLineBreak());
            this.index++;
        } else {
            if (this.index < this.input.length()) {
                Pattern pattern = ESCAPABLE;
                String str = this.input;
                int i = this.index;
                if (pattern.matcher(str.substring(i, i + 1)).matches()) {
                    String str2 = this.input;
                    int i2 = this.index;
                    appendText(str2, i2, i2 + 1);
                    this.index++;
                }
            }
            appendText("\\");
        }
        return true;
    }

    private boolean parseBackticks() {
        String matched;
        String ticks = match(TICKS_HERE);
        if (ticks == null) {
            return false;
        }
        int afterOpenTicks = this.index;
        do {
            String match = match(TICKS);
            matched = match;
            if (match == null) {
                this.index = afterOpenTicks;
                appendText(ticks);
                return true;
            }
        } while (!matched.equals(ticks));
        Code node = new Code();
        node.setLiteral(WHITESPACE.matcher(this.input.substring(afterOpenTicks, this.index - ticks.length()).trim()).replaceAll(" "));
        appendNode(node);
        return true;
    }

    private boolean parseDelimiters(DelimiterProcessor delimiterProcessor, char delimiterChar) {
        DelimiterData res = scanDelimiters(delimiterProcessor, delimiterChar);
        if (res == null) {
            return false;
        }
        int length = res.count;
        int startIndex = this.index;
        int i = this.index + length;
        this.index = i;
        Delimiter delimiter = new Delimiter(appendText(this.input, startIndex, i), delimiterChar, res.canOpen, res.canClose, this.lastDelimiter);
        this.lastDelimiter = delimiter;
        delimiter.length = length;
        this.lastDelimiter.originalLength = length;
        if (this.lastDelimiter.previous == null) {
            return true;
        }
        this.lastDelimiter.previous.next = this.lastDelimiter;
        return true;
    }

    private boolean parseOpenBracket() {
        int startIndex = this.index;
        this.index++;
        addBracket(Bracket.link(appendText("["), startIndex, this.lastBracket, this.lastDelimiter));
        return true;
    }

    private boolean parseBang() {
        int startIndex = this.index;
        this.index++;
        if (peek() == '[') {
            this.index++;
            addBracket(Bracket.image(appendText("!["), startIndex + 1, this.lastBracket, this.lastDelimiter));
        } else {
            appendText("!");
        }
        return true;
    }

    private boolean parseCloseBracket() {
        Link link;
        this.index++;
        int startIndex = this.index;
        Bracket opener = this.lastBracket;
        if (opener == null) {
            appendText("]");
            return true;
        } else if (!opener.allowed) {
            appendText("]");
            removeLastBracket();
            return true;
        } else {
            String dest = null;
            String title = null;
            boolean isLinkOrImage = false;
            if (peek() == '(') {
                this.index++;
                spnl();
                String parseLinkDestination = parseLinkDestination();
                dest = parseLinkDestination;
                if (parseLinkDestination != null) {
                    spnl();
                    Pattern pattern = WHITESPACE;
                    String str = this.input;
                    int i = this.index;
                    if (pattern.matcher(str.substring(i - 1, i)).matches()) {
                        title = parseLinkTitle();
                        spnl();
                    }
                    if (peek() == ')') {
                        this.index++;
                        isLinkOrImage = true;
                    } else {
                        this.index = startIndex;
                    }
                }
            }
            if (!isLinkOrImage) {
                int beforeLabel = this.index;
                int labelLength = parseLinkLabel();
                String ref = null;
                if (labelLength > 2) {
                    ref = this.input.substring(beforeLabel, beforeLabel + labelLength);
                } else if (!opener.bracketAfter) {
                    ref = this.input.substring(opener.index, startIndex);
                }
                if (!(ref == null || (link = this.referenceMap.get(Escaping.normalizeReference(ref))) == null)) {
                    dest = link.getDestination();
                    title = link.getTitle();
                    isLinkOrImage = true;
                }
            }
            if (isLinkOrImage) {
                Node linkOrImage = opener.image ? new Image(dest, title) : new Link(dest, title);
                Node node = opener.node.getNext();
                while (node != null) {
                    Node next = node.getNext();
                    linkOrImage.appendChild(node);
                    node = next;
                }
                appendNode(linkOrImage);
                processDelimiters(opener.previousDelimiter);
                mergeChildTextNodes(linkOrImage);
                opener.node.unlink();
                removeLastBracket();
                if (!opener.image) {
                    for (Bracket bracket = this.lastBracket; bracket != null; bracket = bracket.previous) {
                        if (!bracket.image) {
                            bracket.allowed = false;
                        }
                    }
                }
                return true;
            }
            appendText("]");
            removeLastBracket();
            this.index = startIndex;
            return true;
        }
    }

    private void addBracket(Bracket bracket) {
        Bracket bracket2 = this.lastBracket;
        if (bracket2 != null) {
            bracket2.bracketAfter = true;
        }
        this.lastBracket = bracket;
    }

    private void removeLastBracket() {
        this.lastBracket = this.lastBracket.previous;
    }

    private String parseLinkDestination() {
        String res = match(LINK_DESTINATION_BRACES);
        if (res == null) {
            int startIndex = this.index;
            parseLinkDestinationWithBalancedParens();
            return Escaping.unescapeString(this.input.substring(startIndex, this.index));
        } else if (res.length() == 2) {
            return "";
        } else {
            return Escaping.unescapeString(res.substring(1, res.length() - 1));
        }
    }

    private void parseLinkDestinationWithBalancedParens() {
        int parens = 0;
        while (true) {
            char c = peek();
            switch (c) {
                case 0:
                    return;
                case ' ':
                    return;
                case '(':
                    parens++;
                    break;
                case ')':
                    if (parens != 0) {
                        parens--;
                        break;
                    } else {
                        return;
                    }
                case '\\':
                    if (this.index + 1 >= this.input.length()) {
                        break;
                    } else {
                        Pattern pattern = ESCAPABLE;
                        String str = this.input;
                        int i = this.index;
                        if (!pattern.matcher(str.substring(i + 1, i + 2)).matches()) {
                            break;
                        } else {
                            this.index++;
                            break;
                        }
                    }
                default:
                    if (!Character.isISOControl(c)) {
                        break;
                    } else {
                        return;
                    }
            }
            this.index++;
        }
    }

    private String parseLinkTitle() {
        String title = match(LINK_TITLE);
        if (title != null) {
            return Escaping.unescapeString(title.substring(1, title.length() - 1));
        }
        return null;
    }

    private int parseLinkLabel() {
        String m = match(LINK_LABEL);
        if (m == null || m.length() > 1001) {
            return 0;
        }
        return m.length();
    }

    private boolean parseAutolink() {
        String match = match(EMAIL_AUTOLINK);
        String m = match;
        if (match != null) {
            String dest = m.substring(1, m.length() - 1);
            Link node = new Link(MailTo.MAILTO_SCHEME + dest, (String) null);
            node.appendChild(new Text(dest));
            appendNode(node);
            return true;
        }
        String match2 = match(AUTOLINK);
        String m2 = match2;
        if (match2 == null) {
            return false;
        }
        String dest2 = m2.substring(1, m2.length() - 1);
        Link node2 = new Link(dest2, (String) null);
        node2.appendChild(new Text(dest2));
        appendNode(node2);
        return true;
    }

    private boolean parseHtmlInline() {
        String m = match(HTML_TAG);
        if (m == null) {
            return false;
        }
        HtmlInline node = new HtmlInline();
        node.setLiteral(m);
        appendNode(node);
        return true;
    }

    private boolean parseEntity() {
        String match = match(ENTITY_HERE);
        String m = match;
        if (match == null) {
            return false;
        }
        appendText(Html5Entities.entityToString(m));
        return true;
    }

    private boolean parseString() {
        int begin = this.index;
        int length = this.input.length();
        while (true) {
            int i = this.index;
            if (i == length || this.specialCharacters.get(this.input.charAt(i))) {
                int i2 = this.index;
            } else {
                this.index++;
            }
        }
        int i22 = this.index;
        if (begin == i22) {
            return false;
        }
        appendText(this.input, begin, i22);
        return true;
    }

    private DelimiterData scanDelimiters(DelimiterProcessor delimiterProcessor, char delimiterChar) {
        boolean canClose;
        String before;
        boolean canOpen;
        char c = delimiterChar;
        int startIndex = this.index;
        int delimiterCount = 0;
        while (true) {
            canClose = true;
            if (peek() != c) {
                break;
            }
            delimiterCount++;
            this.index++;
        }
        if (delimiterCount < delimiterProcessor.getMinLength()) {
            this.index = startIndex;
            return null;
        }
        String after = "\n";
        if (startIndex == 0) {
            before = after;
        } else {
            before = this.input.substring(startIndex - 1, startIndex);
        }
        char charAfter = peek();
        if (charAfter != 0) {
            after = String.valueOf(charAfter);
        }
        Pattern pattern = PUNCTUATION;
        boolean beforeIsPunctuation = pattern.matcher(before).matches();
        Pattern pattern2 = UNICODE_WHITESPACE_CHAR;
        boolean beforeIsWhitespace = pattern2.matcher(before).matches();
        boolean afterIsPunctuation = pattern.matcher(after).matches();
        boolean afterIsWhitespace = pattern2.matcher(after).matches();
        boolean leftFlanking = !afterIsWhitespace && (!afterIsPunctuation || beforeIsWhitespace || beforeIsPunctuation);
        boolean rightFlanking = !beforeIsWhitespace && (!beforeIsPunctuation || afterIsWhitespace || afterIsPunctuation);
        if (c == '_') {
            canOpen = leftFlanking && (!rightFlanking || beforeIsPunctuation);
            if (!rightFlanking || (leftFlanking && !afterIsPunctuation)) {
                canClose = false;
            }
        } else {
            canOpen = leftFlanking && c == delimiterProcessor.getOpeningCharacter();
            canClose = rightFlanking && c == delimiterProcessor.getClosingCharacter();
        }
        this.index = startIndex;
        return new DelimiterData(delimiterCount, canOpen, canClose);
    }

    private void processDelimiters(Delimiter stackBottom) {
        Map<Character, Delimiter> openersBottom = new HashMap<>();
        Delimiter closer = this.lastDelimiter;
        while (closer != null && closer.previous != stackBottom) {
            closer = closer.previous;
        }
        while (closer != null) {
            char delimiterChar = closer.delimiterChar;
            DelimiterProcessor delimiterProcessor = this.delimiterProcessors.get(Character.valueOf(delimiterChar));
            if (!closer.canClose || delimiterProcessor == null) {
                closer = closer.next;
            } else {
                char openingDelimiterChar = delimiterProcessor.getOpeningCharacter();
                int useDelims = 0;
                boolean openerFound = false;
                boolean potentialOpenerFound = false;
                Delimiter opener = closer.previous;
                while (true) {
                    if (opener == null || opener == stackBottom || opener == openersBottom.get(Character.valueOf(delimiterChar))) {
                        break;
                    }
                    if (opener.canOpen && opener.delimiterChar == openingDelimiterChar) {
                        potentialOpenerFound = true;
                        useDelims = delimiterProcessor.getDelimiterUse(opener, closer);
                        if (useDelims > 0) {
                            openerFound = true;
                            break;
                        }
                    }
                    opener = opener.previous;
                }
                if (!openerFound) {
                    if (!potentialOpenerFound) {
                        openersBottom.put(Character.valueOf(delimiterChar), closer.previous);
                        if (!closer.canOpen) {
                            removeDelimiterKeepNode(closer);
                        }
                    }
                    closer = closer.next;
                } else {
                    Text openerNode = opener.node;
                    Text closerNode = closer.node;
                    opener.length -= useDelims;
                    closer.length -= useDelims;
                    openerNode.setLiteral(openerNode.getLiteral().substring(0, openerNode.getLiteral().length() - useDelims));
                    closerNode.setLiteral(closerNode.getLiteral().substring(0, closerNode.getLiteral().length() - useDelims));
                    removeDelimitersBetween(opener, closer);
                    mergeTextNodesBetweenExclusive(openerNode, closerNode);
                    delimiterProcessor.process(openerNode, closerNode, useDelims);
                    if (opener.length == 0) {
                        removeDelimiterAndNode(opener);
                    }
                    if (closer.length == 0) {
                        Delimiter next = closer.next;
                        removeDelimiterAndNode(closer);
                        closer = next;
                    }
                }
            }
        }
        while (true) {
            Delimiter delimiter = this.lastDelimiter;
            if (delimiter != null && delimiter != stackBottom) {
                removeDelimiterKeepNode(delimiter);
            } else {
                return;
            }
        }
    }

    private void removeDelimitersBetween(Delimiter opener, Delimiter closer) {
        Delimiter delimiter = closer.previous;
        while (delimiter != null && delimiter != opener) {
            Delimiter previousDelimiter = delimiter.previous;
            removeDelimiterKeepNode(delimiter);
            delimiter = previousDelimiter;
        }
    }

    private void removeDelimiterAndNode(Delimiter delim) {
        delim.node.unlink();
        removeDelimiter(delim);
    }

    private void removeDelimiterKeepNode(Delimiter delim) {
        removeDelimiter(delim);
    }

    private void removeDelimiter(Delimiter delim) {
        if (delim.previous != null) {
            delim.previous.next = delim.next;
        }
        if (delim.next == null) {
            this.lastDelimiter = delim.previous;
            return;
        }
        delim.next.previous = delim.previous;
    }

    private void mergeTextNodesBetweenExclusive(Node fromNode, Node toNode) {
        if (fromNode != toNode && fromNode.getNext() != toNode) {
            mergeTextNodesInclusive(fromNode.getNext(), toNode.getPrevious());
        }
    }

    private void mergeChildTextNodes(Node node) {
        if (node.getFirstChild() != node.getLastChild()) {
            mergeTextNodesInclusive(node.getFirstChild(), node.getLastChild());
        }
    }

    private void mergeTextNodesInclusive(Node fromNode, Node toNode) {
        Text first = null;
        Text last = null;
        int length = 0;
        for (Node node = fromNode; node != null; node = node.getNext()) {
            if (node instanceof Text) {
                Text text = (Text) node;
                if (first == null) {
                    first = text;
                }
                length += text.getLiteral().length();
                last = text;
            } else {
                mergeIfNeeded(first, last, length);
                first = null;
                last = null;
                length = 0;
            }
            if (node == toNode) {
                break;
            }
        }
        mergeIfNeeded(first, last, length);
    }

    private void mergeIfNeeded(Text first, Text last, int textLength) {
        if (first != null && last != null && first != last) {
            StringBuilder sb = new StringBuilder(textLength);
            sb.append(first.getLiteral());
            Node node = first.getNext();
            Node stop = last.getNext();
            while (node != stop) {
                sb.append(((Text) node).getLiteral());
                Node unlink = node;
                node = node.getNext();
                unlink.unlink();
            }
            first.setLiteral(sb.toString());
        }
    }

    private static class DelimiterData {
        final boolean canClose;
        final boolean canOpen;
        final int count;

        DelimiterData(int count2, boolean canOpen2, boolean canClose2) {
            this.count = count2;
            this.canOpen = canOpen2;
            this.canClose = canClose2;
        }
    }
}
