package org.commonmark.parser;

import java.io.IOException;
import java.io.Reader;
import java.util.ArrayList;
import java.util.List;
import java.util.Set;
import org.commonmark.Extension;
import org.commonmark.internal.DocumentParser;
import org.commonmark.internal.InlineParserImpl;
import org.commonmark.node.Block;
import org.commonmark.node.Node;
import org.commonmark.parser.block.BlockParserFactory;
import org.commonmark.parser.delimiter.DelimiterProcessor;

public class Parser {
    private final List<BlockParserFactory> blockParserFactories;
    private final List<DelimiterProcessor> delimiterProcessors;
    private final InlineParserFactory inlineParserFactory;
    private final List<PostProcessor> postProcessors;

    public interface ParserExtension extends Extension {
        void extend(Builder builder);
    }

    private Parser(Builder builder) {
        this.blockParserFactories = DocumentParser.calculateBlockParserFactories(builder.blockParserFactories, builder.enabledBlockTypes);
        this.inlineParserFactory = builder.inlineParserFactory;
        this.postProcessors = builder.postProcessors;
        this.delimiterProcessors = builder.delimiterProcessors;
        getInlineParser();
    }

    public static Builder builder() {
        return new Builder();
    }

    public Node parse(String input) {
        return postProcess(new DocumentParser(this.blockParserFactories, getInlineParser()).parse(input));
    }

    public Node parseReader(Reader input) throws IOException {
        return postProcess(new DocumentParser(this.blockParserFactories, getInlineParser()).parse(input));
    }

    private InlineParser getInlineParser() {
        if (this.inlineParserFactory == null) {
            return new InlineParserImpl(this.delimiterProcessors);
        }
        return this.inlineParserFactory.create(new CustomInlineParserContext(this.delimiterProcessors));
    }

    private Node postProcess(Node document) {
        for (PostProcessor postProcessor : this.postProcessors) {
            document = postProcessor.process(document);
        }
        return document;
    }

    private class CustomInlineParserContext implements InlineParserContext {
        private List<DelimiterProcessor> delimiterProcessors;

        CustomInlineParserContext(List<DelimiterProcessor> delimiterProcessors2) {
            this.delimiterProcessors = delimiterProcessors2;
        }

        public List<DelimiterProcessor> getCustomDelimiterProcessors() {
            return this.delimiterProcessors;
        }
    }

    public static class Builder {
        /* access modifiers changed from: private */
        public final List<BlockParserFactory> blockParserFactories = new ArrayList();
        /* access modifiers changed from: private */
        public final List<DelimiterProcessor> delimiterProcessors = new ArrayList();
        /* access modifiers changed from: private */
        public Set<Class<? extends Block>> enabledBlockTypes = DocumentParser.getDefaultBlockParserTypes();
        /* access modifiers changed from: private */
        public InlineParserFactory inlineParserFactory = null;
        /* access modifiers changed from: private */
        public final List<PostProcessor> postProcessors = new ArrayList();

        public Parser build() {
            return new Parser(this);
        }

        public Builder extensions(Iterable<? extends Extension> extensions) {
            for (Extension extension : extensions) {
                if (extension instanceof ParserExtension) {
                    ((ParserExtension) extension).extend(this);
                }
            }
            return this;
        }

        public Builder enabledBlockTypes(Set<Class<? extends Block>> enabledBlockTypes2) {
            this.enabledBlockTypes = enabledBlockTypes2;
            return this;
        }

        public Builder customBlockParserFactory(BlockParserFactory blockParserFactory) {
            this.blockParserFactories.add(blockParserFactory);
            return this;
        }

        public Builder customDelimiterProcessor(DelimiterProcessor delimiterProcessor) {
            this.delimiterProcessors.add(delimiterProcessor);
            return this;
        }

        public Builder postProcessor(PostProcessor postProcessor) {
            this.postProcessors.add(postProcessor);
            return this;
        }

        public Builder inlineParserFactory(InlineParserFactory inlineParserFactory2) {
            this.inlineParserFactory = inlineParserFactory2;
            return this;
        }
    }
}
