package org.commonmark.renderer.html;

import java.util.ArrayList;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import org.commonmark.Extension;
import org.commonmark.internal.renderer.NodeRendererMap;
import org.commonmark.internal.util.Escaping;
import org.commonmark.node.Node;
import org.commonmark.renderer.NodeRenderer;
import org.commonmark.renderer.Renderer;

public class HtmlRenderer implements Renderer {
    /* access modifiers changed from: private */
    public final List<AttributeProviderFactory> attributeProviderFactories;
    /* access modifiers changed from: private */
    public final boolean escapeHtml;
    /* access modifiers changed from: private */
    public final List<HtmlNodeRendererFactory> nodeRendererFactories;
    /* access modifiers changed from: private */
    public final boolean percentEncodeUrls;
    /* access modifiers changed from: private */
    public final String softbreak;

    public interface HtmlRendererExtension extends Extension {
        void extend(Builder builder);
    }

    private HtmlRenderer(Builder builder) {
        this.softbreak = builder.softbreak;
        this.escapeHtml = builder.escapeHtml;
        this.percentEncodeUrls = builder.percentEncodeUrls;
        this.attributeProviderFactories = new ArrayList(builder.attributeProviderFactories);
        ArrayList arrayList = new ArrayList(builder.nodeRendererFactories.size() + 1);
        this.nodeRendererFactories = arrayList;
        arrayList.addAll(builder.nodeRendererFactories);
        arrayList.add(new HtmlNodeRendererFactory() {
            public NodeRenderer create(HtmlNodeRendererContext context) {
                return new CoreHtmlNodeRenderer(context);
            }
        });
    }

    public static Builder builder() {
        return new Builder();
    }

    public void render(Node node, Appendable output) {
        new RendererContext(new HtmlWriter(output)).render(node);
    }

    public String render(Node node) {
        StringBuilder sb = new StringBuilder();
        render(node, sb);
        return sb.toString();
    }

    public static class Builder {
        /* access modifiers changed from: private */
        public List<AttributeProviderFactory> attributeProviderFactories = new ArrayList();
        /* access modifiers changed from: private */
        public boolean escapeHtml = false;
        /* access modifiers changed from: private */
        public List<HtmlNodeRendererFactory> nodeRendererFactories = new ArrayList();
        /* access modifiers changed from: private */
        public boolean percentEncodeUrls = false;
        /* access modifiers changed from: private */
        public String softbreak = "\n";

        public HtmlRenderer build() {
            return new HtmlRenderer(this);
        }

        public Builder softbreak(String softbreak2) {
            this.softbreak = softbreak2;
            return this;
        }

        public Builder escapeHtml(boolean escapeHtml2) {
            this.escapeHtml = escapeHtml2;
            return this;
        }

        public Builder percentEncodeUrls(boolean percentEncodeUrls2) {
            this.percentEncodeUrls = percentEncodeUrls2;
            return this;
        }

        public Builder attributeProviderFactory(AttributeProviderFactory attributeProviderFactory) {
            this.attributeProviderFactories.add(attributeProviderFactory);
            return this;
        }

        public Builder nodeRendererFactory(HtmlNodeRendererFactory nodeRendererFactory) {
            this.nodeRendererFactories.add(nodeRendererFactory);
            return this;
        }

        public Builder extensions(Iterable<? extends Extension> extensions) {
            for (Extension extension : extensions) {
                if (extension instanceof HtmlRendererExtension) {
                    ((HtmlRendererExtension) extension).extend(this);
                }
            }
            return this;
        }
    }

    private class RendererContext implements HtmlNodeRendererContext, AttributeProviderContext {
        private final List<AttributeProvider> attributeProviders;
        private final HtmlWriter htmlWriter;
        private final NodeRendererMap nodeRendererMap;

        private RendererContext(HtmlWriter htmlWriter2) {
            this.nodeRendererMap = new NodeRendererMap();
            this.htmlWriter = htmlWriter2;
            this.attributeProviders = new ArrayList(HtmlRenderer.this.attributeProviderFactories.size());
            for (AttributeProviderFactory attributeProviderFactory : HtmlRenderer.this.attributeProviderFactories) {
                this.attributeProviders.add(attributeProviderFactory.create(this));
            }
            for (int i = HtmlRenderer.this.nodeRendererFactories.size() - 1; i >= 0; i--) {
                this.nodeRendererMap.add(((HtmlNodeRendererFactory) HtmlRenderer.this.nodeRendererFactories.get(i)).create(this));
            }
        }

        public boolean shouldEscapeHtml() {
            return HtmlRenderer.this.escapeHtml;
        }

        public String encodeUrl(String url) {
            if (HtmlRenderer.this.percentEncodeUrls) {
                return Escaping.percentEncodeUrl(url);
            }
            return url;
        }

        public Map<String, String> extendAttributes(Node node, String tagName, Map<String, String> attributes) {
            Map<String, String> attrs = new LinkedHashMap<>(attributes);
            setCustomAttributes(node, tagName, attrs);
            return attrs;
        }

        public HtmlWriter getWriter() {
            return this.htmlWriter;
        }

        public String getSoftbreak() {
            return HtmlRenderer.this.softbreak;
        }

        public void render(Node node) {
            this.nodeRendererMap.render(node);
        }

        private void setCustomAttributes(Node node, String tagName, Map<String, String> attrs) {
            for (AttributeProvider attributeProvider : this.attributeProviders) {
                attributeProvider.setAttributes(node, tagName, attrs);
            }
        }
    }
}
