package ru.noties.markwon;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import org.commonmark.node.BlockQuote;
import org.commonmark.node.BulletList;
import org.commonmark.node.Code;
import org.commonmark.node.CustomBlock;
import org.commonmark.node.CustomNode;
import org.commonmark.node.Document;
import org.commonmark.node.Emphasis;
import org.commonmark.node.FencedCodeBlock;
import org.commonmark.node.HardLineBreak;
import org.commonmark.node.Heading;
import org.commonmark.node.HtmlBlock;
import org.commonmark.node.HtmlInline;
import org.commonmark.node.Image;
import org.commonmark.node.IndentedCodeBlock;
import org.commonmark.node.Link;
import org.commonmark.node.ListItem;
import org.commonmark.node.Node;
import org.commonmark.node.OrderedList;
import org.commonmark.node.Paragraph;
import org.commonmark.node.SoftLineBreak;
import org.commonmark.node.StrongEmphasis;
import org.commonmark.node.Text;
import org.commonmark.node.ThematicBreak;
import ru.noties.markwon.MarkwonVisitor;

class MarkwonVisitorImpl implements MarkwonVisitor {
    private final SpannableBuilder builder;
    private final MarkwonConfiguration configuration;
    private final Map<Class<? extends Node>, MarkwonVisitor.NodeVisitor<? extends Node>> nodes;
    private final RenderProps renderProps;

    MarkwonVisitorImpl(MarkwonConfiguration configuration2, RenderProps renderProps2, SpannableBuilder builder2, Map<Class<? extends Node>, MarkwonVisitor.NodeVisitor<? extends Node>> nodes2) {
        this.configuration = configuration2;
        this.renderProps = renderProps2;
        this.builder = builder2;
        this.nodes = nodes2;
    }

    public void visit(BlockQuote blockQuote) {
        visit((Node) blockQuote);
    }

    public void visit(BulletList bulletList) {
        visit((Node) bulletList);
    }

    public void visit(Code code) {
        visit((Node) code);
    }

    public void visit(Document document) {
        visit((Node) document);
    }

    public void visit(Emphasis emphasis) {
        visit((Node) emphasis);
    }

    public void visit(FencedCodeBlock fencedCodeBlock) {
        visit((Node) fencedCodeBlock);
    }

    public void visit(HardLineBreak hardLineBreak) {
        visit((Node) hardLineBreak);
    }

    public void visit(Heading heading) {
        visit((Node) heading);
    }

    public void visit(ThematicBreak thematicBreak) {
        visit((Node) thematicBreak);
    }

    public void visit(HtmlInline htmlInline) {
        visit((Node) htmlInline);
    }

    public void visit(HtmlBlock htmlBlock) {
        visit((Node) htmlBlock);
    }

    public void visit(Image image) {
        visit((Node) image);
    }

    public void visit(IndentedCodeBlock indentedCodeBlock) {
        visit((Node) indentedCodeBlock);
    }

    public void visit(Link link) {
        visit((Node) link);
    }

    public void visit(ListItem listItem) {
        visit((Node) listItem);
    }

    public void visit(OrderedList orderedList) {
        visit((Node) orderedList);
    }

    public void visit(Paragraph paragraph) {
        visit((Node) paragraph);
    }

    public void visit(SoftLineBreak softLineBreak) {
        visit((Node) softLineBreak);
    }

    public void visit(StrongEmphasis strongEmphasis) {
        visit((Node) strongEmphasis);
    }

    public void visit(Text text) {
        visit((Node) text);
    }

    public void visit(CustomBlock customBlock) {
        visit((Node) customBlock);
    }

    public void visit(CustomNode customNode) {
        visit((Node) customNode);
    }

    private void visit(Node node) {
        MarkwonVisitor.NodeVisitor<Node> nodeVisitor = this.nodes.get(node.getClass());
        if (nodeVisitor != null) {
            nodeVisitor.visit(this, node);
        } else {
            visitChildren(node);
        }
    }

    public MarkwonConfiguration configuration() {
        return this.configuration;
    }

    public RenderProps renderProps() {
        return this.renderProps;
    }

    public SpannableBuilder builder() {
        return this.builder;
    }

    public void visitChildren(Node parent) {
        Node node = parent.getFirstChild();
        while (node != null) {
            Node next = node.getNext();
            node.accept(this);
            node = next;
        }
    }

    public boolean hasNext(Node node) {
        return node.getNext() != null;
    }

    public void ensureNewLine() {
        if (this.builder.length() > 0 && 10 != this.builder.lastChar()) {
            this.builder.append(10);
        }
    }

    public void forceNewLine() {
        this.builder.append(10);
    }

    public int length() {
        return this.builder.length();
    }

    public void setSpans(int start, Object spans) {
        SpannableBuilder spannableBuilder = this.builder;
        SpannableBuilder.setSpans(spannableBuilder, spans, start, spannableBuilder.length());
    }

    public void clear() {
        this.renderProps.clearAll();
        this.builder.clear();
    }

    public <N extends Node> void setSpansForNode(N node, int start) {
        setSpansForNode(node.getClass(), start);
    }

    public <N extends Node> void setSpansForNode(Class<N> node, int start) {
        setSpans(start, this.configuration.spansFactory().require(node).getSpans(this.configuration, this.renderProps));
    }

    public <N extends Node> void setSpansForNodeOptional(N node, int start) {
        setSpansForNodeOptional(node.getClass(), start);
    }

    public <N extends Node> void setSpansForNodeOptional(Class<N> node, int start) {
        SpanFactory factory = this.configuration.spansFactory().get(node);
        if (factory != null) {
            setSpans(start, factory.getSpans(this.configuration, this.renderProps));
        }
    }

    static class BuilderImpl implements MarkwonVisitor.Builder {
        private final Map<Class<? extends Node>, MarkwonVisitor.NodeVisitor<? extends Node>> nodes = new HashMap();

        BuilderImpl() {
        }

        public <N extends Node> MarkwonVisitor.Builder on(Class<N> node, MarkwonVisitor.NodeVisitor<? super N> nodeVisitor) {
            if (nodeVisitor == null) {
                this.nodes.remove(node);
            } else {
                this.nodes.put(node, nodeVisitor);
            }
            return this;
        }

        public MarkwonVisitor build(MarkwonConfiguration configuration, RenderProps renderProps) {
            return new MarkwonVisitorImpl(configuration, renderProps, new SpannableBuilder(), Collections.unmodifiableMap(this.nodes));
        }
    }
}
