package ru.noties.markwon;

import android.text.SpannableStringBuilder;
import android.text.Spanned;
import java.util.ArrayDeque;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Deque;
import java.util.Iterator;
import java.util.List;

public class SpannableBuilder implements Appendable, CharSequence {
    private final StringBuilder builder;
    private final Deque<Span> spans;

    public static void setSpans(SpannableBuilder builder2, Object spans2, int start, int end) {
        if (spans2 != null && isPositionValid(builder2.length(), start, end)) {
            if (spans2.getClass().isArray()) {
                for (Object o : (Object[]) spans2) {
                    builder2.setSpan(o, start, end, 33);
                }
                return;
            }
            builder2.setSpan(spans2, start, end, 33);
        }
    }

    static boolean isPositionValid(int length, int start, int end) {
        return end > start && start >= 0 && end <= length;
    }

    public SpannableBuilder() {
        this("");
    }

    public SpannableBuilder(CharSequence cs) {
        this.spans = new ArrayDeque(8);
        this.builder = new StringBuilder(cs);
        copySpans(0, cs);
    }

    public SpannableBuilder append(String text) {
        this.builder.append(text);
        return this;
    }

    public SpannableBuilder append(char c) {
        this.builder.append(c);
        return this;
    }

    public SpannableBuilder append(CharSequence cs) {
        copySpans(length(), cs);
        this.builder.append(cs);
        return this;
    }

    public SpannableBuilder append(CharSequence csq, int start, int end) {
        CharSequence cs = csq.subSequence(start, end);
        copySpans(length(), cs);
        this.builder.append(cs);
        return this;
    }

    public SpannableBuilder append(CharSequence cs, Object span) {
        int length = length();
        append(cs);
        setSpan(span, length);
        return this;
    }

    public SpannableBuilder append(CharSequence cs, Object span, int flags) {
        int length = length();
        append(cs);
        setSpan(span, length, length(), flags);
        return this;
    }

    public SpannableBuilder setSpan(Object span, int start) {
        return setSpan(span, start, length());
    }

    public SpannableBuilder setSpan(Object span, int start, int end) {
        return setSpan(span, start, end, 33);
    }

    public SpannableBuilder setSpan(Object span, int start, int end, int flags) {
        this.spans.push(new Span(span, start, end, flags));
        return this;
    }

    public int length() {
        return this.builder.length();
    }

    public char charAt(int index) {
        return this.builder.charAt(index);
    }

    public CharSequence subSequence(int start, int end) {
        List<Span> spans2 = getSpans(start, end);
        if (spans2.isEmpty()) {
            return this.builder.subSequence(start, end);
        }
        SpannableStringBuilder builder2 = new SpannableStringBuilder(this.builder.subSequence(start, end));
        int length = builder2.length();
        for (Span span : spans2) {
            int s = Math.max(0, span.start - start);
            builder2.setSpan(span.what, s, Math.max(length, (span.end - span.start) + s), span.flags);
        }
        SpannableStringBuilder spannableStringBuilder = builder2;
        return builder2;
    }

    public List<Span> getSpans(int start, int end) {
        int length = length();
        if (!isPositionValid(length, start, end)) {
            return Collections.emptyList();
        }
        if (start == 0 && length == end) {
            List<Span> list = new ArrayList<>(this.spans);
            Collections.reverse(list);
            return Collections.unmodifiableList(list);
        }
        List<Span> list2 = new ArrayList<>(0);
        Iterator<Span> iterator = this.spans.descendingIterator();
        while (iterator.hasNext()) {
            Span span = iterator.next();
            if ((span.start >= start && span.start < end) || ((span.end <= end && span.end > start) || (span.start < start && span.end > end))) {
                list2.add(span);
            }
        }
        return Collections.unmodifiableList(list2);
    }

    public char lastChar() {
        return this.builder.charAt(length() - 1);
    }

    public CharSequence removeFromEnd(int start) {
        int end = length();
        SpannableStringBuilderReversed impl = new SpannableStringBuilderReversed(this.builder.subSequence(start, end));
        Iterator<Span> iterator = this.spans.iterator();
        while (iterator.hasNext()) {
            Span next = iterator.next();
            Span span = next;
            if (next == null) {
                break;
            } else if (span.start >= start && span.end <= end) {
                impl.setSpan(span.what, span.start - start, span.end - start, 33);
                iterator.remove();
            }
        }
        this.builder.replace(start, end, "");
        return impl;
    }

    public String toString() {
        return this.builder.toString();
    }

    public CharSequence text() {
        return spannableStringBuilder();
    }

    public SpannableStringBuilder spannableStringBuilder() {
        SpannableStringBuilderReversed reversed = new SpannableStringBuilderReversed(this.builder);
        for (Span span : this.spans) {
            reversed.setSpan(span.what, span.start, span.end, span.flags);
        }
        return reversed;
    }

    public void clear() {
        this.builder.setLength(0);
        this.spans.clear();
    }

    private void copySpans(int index, CharSequence cs) {
        if (cs instanceof Spanned) {
            Spanned spanned = (Spanned) cs;
            boolean reversed = spanned instanceof SpannableStringBuilderReversed;
            int i = 0;
            Object[] spans2 = spanned.getSpans(0, spanned.length(), Object.class);
            if (spans2 != null) {
                i = spans2.length;
            }
            int length = i;
            if (length <= 0) {
                return;
            }
            if (reversed) {
                for (int i2 = length - 1; i2 >= 0; i2--) {
                    Object o = spans2[i2];
                    setSpan(o, spanned.getSpanStart(o) + index, spanned.getSpanEnd(o) + index, spanned.getSpanFlags(o));
                }
                return;
            }
            for (int i3 = 0; i3 < length; i3++) {
                Object o2 = spans2[i3];
                setSpan(o2, spanned.getSpanStart(o2) + index, spanned.getSpanEnd(o2) + index, spanned.getSpanFlags(o2));
            }
        }
    }

    public static class Span {
        public int end;
        public final int flags;
        public int start;
        public final Object what;

        Span(Object what2, int start2, int end2, int flags2) {
            this.what = what2;
            this.start = start2;
            this.end = end2;
            this.flags = flags2;
        }
    }

    static class SpannableStringBuilderReversed extends SpannableStringBuilder {
        SpannableStringBuilderReversed(CharSequence text) {
            super(text);
        }
    }
}
