package ru.noties.markwon.core;

import android.text.Spanned;
import android.text.method.LinkMovementMethod;
import android.widget.TextView;
import kotlin.text.Typography;
import org.commonmark.node.Block;
import org.commonmark.node.BlockQuote;
import org.commonmark.node.BulletList;
import org.commonmark.node.Code;
import org.commonmark.node.Emphasis;
import org.commonmark.node.FencedCodeBlock;
import org.commonmark.node.HardLineBreak;
import org.commonmark.node.Heading;
import org.commonmark.node.IndentedCodeBlock;
import org.commonmark.node.Link;
import org.commonmark.node.ListBlock;
import org.commonmark.node.ListItem;
import org.commonmark.node.Node;
import org.commonmark.node.OrderedList;
import org.commonmark.node.Paragraph;
import org.commonmark.node.SoftLineBreak;
import org.commonmark.node.StrongEmphasis;
import org.commonmark.node.Text;
import org.commonmark.node.ThematicBreak;
import ru.noties.markwon.AbstractMarkwonPlugin;
import ru.noties.markwon.MarkwonSpansFactory;
import ru.noties.markwon.MarkwonVisitor;
import ru.noties.markwon.core.CoreProps;
import ru.noties.markwon.core.factory.BlockQuoteSpanFactory;
import ru.noties.markwon.core.factory.CodeBlockSpanFactory;
import ru.noties.markwon.core.factory.CodeSpanFactory;
import ru.noties.markwon.core.factory.EmphasisSpanFactory;
import ru.noties.markwon.core.factory.HeadingSpanFactory;
import ru.noties.markwon.core.factory.LinkSpanFactory;
import ru.noties.markwon.core.factory.ListItemSpanFactory;
import ru.noties.markwon.core.factory.StrongEmphasisSpanFactory;
import ru.noties.markwon.core.factory.ThematicBreakSpanFactory;
import ru.noties.markwon.core.spans.OrderedListItemSpan;
import ru.noties.markwon.priority.Priority;

public class CorePlugin extends AbstractMarkwonPlugin {
    public static CorePlugin create() {
        return new CorePlugin();
    }

    protected CorePlugin() {
    }

    public void configureVisitor(MarkwonVisitor.Builder builder) {
        text(builder);
        strongEmphasis(builder);
        emphasis(builder);
        blockQuote(builder);
        code(builder);
        fencedCodeBlock(builder);
        indentedCodeBlock(builder);
        bulletList(builder);
        orderedList(builder);
        listItem(builder);
        thematicBreak(builder);
        heading(builder);
        softLineBreak(builder);
        hardLineBreak(builder);
        paragraph(builder);
        link(builder);
    }

    public void configureSpansFactory(MarkwonSpansFactory.Builder builder) {
        CodeBlockSpanFactory codeBlockSpanFactory = new CodeBlockSpanFactory();
        builder.setFactory(StrongEmphasis.class, new StrongEmphasisSpanFactory()).setFactory(Emphasis.class, new EmphasisSpanFactory()).setFactory(BlockQuote.class, new BlockQuoteSpanFactory()).setFactory(Code.class, new CodeSpanFactory()).setFactory(FencedCodeBlock.class, codeBlockSpanFactory).setFactory(IndentedCodeBlock.class, codeBlockSpanFactory).setFactory(ListItem.class, new ListItemSpanFactory()).setFactory(Heading.class, new HeadingSpanFactory()).setFactory(Link.class, new LinkSpanFactory()).setFactory(ThematicBreak.class, new ThematicBreakSpanFactory());
    }

    public Priority priority() {
        return Priority.none();
    }

    public void beforeSetText(TextView textView, Spanned markdown) {
        OrderedListItemSpan.measure(textView, markdown);
    }

    public void afterSetText(TextView textView) {
        if (textView.getMovementMethod() == null) {
            textView.setMovementMethod(LinkMovementMethod.getInstance());
        }
    }

    private static void text(MarkwonVisitor.Builder builder) {
        builder.on(Text.class, new MarkwonVisitor.NodeVisitor<Text>() {
            public void visit(MarkwonVisitor visitor, Text text) {
                visitor.builder().append(text.getLiteral());
            }
        });
    }

    private static void strongEmphasis(MarkwonVisitor.Builder builder) {
        builder.on(StrongEmphasis.class, new MarkwonVisitor.NodeVisitor<StrongEmphasis>() {
            public void visit(MarkwonVisitor visitor, StrongEmphasis strongEmphasis) {
                int length = visitor.length();
                visitor.visitChildren(strongEmphasis);
                visitor.setSpansForNodeOptional(strongEmphasis, length);
            }
        });
    }

    private static void emphasis(MarkwonVisitor.Builder builder) {
        builder.on(Emphasis.class, new MarkwonVisitor.NodeVisitor<Emphasis>() {
            public void visit(MarkwonVisitor visitor, Emphasis emphasis) {
                int length = visitor.length();
                visitor.visitChildren(emphasis);
                visitor.setSpansForNodeOptional(emphasis, length);
            }
        });
    }

    private static void blockQuote(MarkwonVisitor.Builder builder) {
        builder.on(BlockQuote.class, new MarkwonVisitor.NodeVisitor<BlockQuote>() {
            public void visit(MarkwonVisitor visitor, BlockQuote blockQuote) {
                visitor.ensureNewLine();
                int length = visitor.length();
                visitor.visitChildren(blockQuote);
                visitor.setSpansForNodeOptional(blockQuote, length);
                if (visitor.hasNext(blockQuote)) {
                    visitor.ensureNewLine();
                    visitor.forceNewLine();
                }
            }
        });
    }

    private static void code(MarkwonVisitor.Builder builder) {
        builder.on(Code.class, new MarkwonVisitor.NodeVisitor<Code>() {
            public void visit(MarkwonVisitor visitor, Code code) {
                int length = visitor.length();
                visitor.builder().append((char) Typography.nbsp).append(code.getLiteral()).append((char) Typography.nbsp);
                visitor.setSpansForNodeOptional(code, length);
            }
        });
    }

    private static void fencedCodeBlock(MarkwonVisitor.Builder builder) {
        builder.on(FencedCodeBlock.class, new MarkwonVisitor.NodeVisitor<FencedCodeBlock>() {
            public void visit(MarkwonVisitor visitor, FencedCodeBlock fencedCodeBlock) {
                CorePlugin.visitCodeBlock(visitor, fencedCodeBlock.getInfo(), fencedCodeBlock.getLiteral(), fencedCodeBlock);
            }
        });
    }

    private static void indentedCodeBlock(MarkwonVisitor.Builder builder) {
        builder.on(IndentedCodeBlock.class, new MarkwonVisitor.NodeVisitor<IndentedCodeBlock>() {
            public void visit(MarkwonVisitor visitor, IndentedCodeBlock indentedCodeBlock) {
                CorePlugin.visitCodeBlock(visitor, (String) null, indentedCodeBlock.getLiteral(), indentedCodeBlock);
            }
        });
    }

    static void visitCodeBlock(MarkwonVisitor visitor, String info, String code, Node node) {
        visitor.ensureNewLine();
        int length = visitor.length();
        visitor.builder().append((char) Typography.nbsp).append(10).append(visitor.configuration().syntaxHighlight().highlight(info, code));
        visitor.ensureNewLine();
        visitor.builder().append((char) Typography.nbsp);
        visitor.setSpansForNodeOptional(node, length);
        if (visitor.hasNext(node)) {
            visitor.ensureNewLine();
            visitor.forceNewLine();
        }
    }

    private static void bulletList(MarkwonVisitor.Builder builder) {
        builder.on(BulletList.class, new SimpleBlockNodeVisitor());
    }

    private static void orderedList(MarkwonVisitor.Builder builder) {
        builder.on(OrderedList.class, new SimpleBlockNodeVisitor());
    }

    private static void listItem(MarkwonVisitor.Builder builder) {
        builder.on(ListItem.class, new MarkwonVisitor.NodeVisitor<ListItem>() {
            public void visit(MarkwonVisitor visitor, ListItem listItem) {
                int length = visitor.length();
                visitor.visitChildren(listItem);
                Block parent = listItem.getParent();
                if (parent instanceof OrderedList) {
                    int start = ((OrderedList) parent).getStartNumber();
                    CoreProps.LIST_ITEM_TYPE.set(visitor.renderProps(), CoreProps.ListItemType.ORDERED);
                    CoreProps.ORDERED_LIST_ITEM_NUMBER.set(visitor.renderProps(), Integer.valueOf(start));
                    OrderedList orderedList = (OrderedList) parent;
                    orderedList.setStartNumber(orderedList.getStartNumber() + 1);
                } else {
                    CoreProps.LIST_ITEM_TYPE.set(visitor.renderProps(), CoreProps.ListItemType.BULLET);
                    CoreProps.BULLET_LIST_ITEM_LEVEL.set(visitor.renderProps(), Integer.valueOf(CorePlugin.listLevel(listItem)));
                }
                visitor.setSpansForNodeOptional(listItem, length);
                if (visitor.hasNext(listItem)) {
                    visitor.ensureNewLine();
                }
            }
        });
    }

    /* access modifiers changed from: private */
    public static int listLevel(Node node) {
        int level = 0;
        for (Node parent = node.getParent(); parent != null; parent = parent.getParent()) {
            if (parent instanceof ListItem) {
                level++;
            }
        }
        return level;
    }

    private static void thematicBreak(MarkwonVisitor.Builder builder) {
        builder.on(ThematicBreak.class, new MarkwonVisitor.NodeVisitor<ThematicBreak>() {
            public void visit(MarkwonVisitor visitor, ThematicBreak thematicBreak) {
                visitor.ensureNewLine();
                int length = visitor.length();
                visitor.builder().append((char) Typography.nbsp);
                visitor.setSpansForNodeOptional(thematicBreak, length);
                if (visitor.hasNext(thematicBreak)) {
                    visitor.ensureNewLine();
                    visitor.forceNewLine();
                }
            }
        });
    }

    private static void heading(MarkwonVisitor.Builder builder) {
        builder.on(Heading.class, new MarkwonVisitor.NodeVisitor<Heading>() {
            public void visit(MarkwonVisitor visitor, Heading heading) {
                visitor.ensureNewLine();
                int length = visitor.length();
                visitor.visitChildren(heading);
                CoreProps.HEADING_LEVEL.set(visitor.renderProps(), Integer.valueOf(heading.getLevel()));
                visitor.setSpansForNodeOptional(heading, length);
                if (visitor.hasNext(heading)) {
                    visitor.ensureNewLine();
                    visitor.forceNewLine();
                }
            }
        });
    }

    private static void softLineBreak(MarkwonVisitor.Builder builder) {
        builder.on(SoftLineBreak.class, new MarkwonVisitor.NodeVisitor<SoftLineBreak>() {
            public void visit(MarkwonVisitor visitor, SoftLineBreak softLineBreak) {
                visitor.builder().append(' ');
            }
        });
    }

    private static void hardLineBreak(MarkwonVisitor.Builder builder) {
        builder.on(HardLineBreak.class, new MarkwonVisitor.NodeVisitor<HardLineBreak>() {
            public void visit(MarkwonVisitor visitor, HardLineBreak hardLineBreak) {
                visitor.ensureNewLine();
            }
        });
    }

    private static void paragraph(MarkwonVisitor.Builder builder) {
        builder.on(Paragraph.class, new MarkwonVisitor.NodeVisitor<Paragraph>() {
            public void visit(MarkwonVisitor visitor, Paragraph paragraph) {
                boolean inTightList = CorePlugin.isInTightList(paragraph);
                if (!inTightList) {
                    visitor.ensureNewLine();
                }
                int length = visitor.length();
                visitor.visitChildren(paragraph);
                CoreProps.PARAGRAPH_IS_IN_TIGHT_LIST.set(visitor.renderProps(), Boolean.valueOf(inTightList));
                visitor.setSpansForNodeOptional(paragraph, length);
                if (!inTightList && visitor.hasNext(paragraph)) {
                    visitor.ensureNewLine();
                    visitor.forceNewLine();
                }
            }
        });
    }

    /* access modifiers changed from: private */
    public static boolean isInTightList(Paragraph paragraph) {
        Node parent = paragraph.getParent();
        if (parent == null) {
            return false;
        }
        Node gramps = parent.getParent();
        if (gramps instanceof ListBlock) {
            return ((ListBlock) gramps).isTight();
        }
        return false;
    }

    private static void link(MarkwonVisitor.Builder builder) {
        builder.on(Link.class, new MarkwonVisitor.NodeVisitor<Link>() {
            public void visit(MarkwonVisitor visitor, Link link) {
                int length = visitor.length();
                visitor.visitChildren(link);
                CoreProps.LINK_DESTINATION.set(visitor.renderProps(), visitor.configuration().urlProcessor().process(link.getDestination()));
                visitor.setSpansForNodeOptional(link, length);
            }
        });
    }
}
