package ru.noties.markwon.core;

import android.content.Context;
import android.graphics.Paint;
import android.graphics.Typeface;
import android.text.TextPaint;
import java.util.Arrays;
import java.util.Locale;
import ru.noties.markwon.utils.ColorUtils;
import ru.noties.markwon.utils.Dip;

public class MarkwonTheme {
    protected static final int BLOCK_QUOTE_DEF_COLOR_ALPHA = 25;
    protected static final int CODE_DEF_BACKGROUND_COLOR_ALPHA = 25;
    protected static final float CODE_DEF_TEXT_SIZE_RATIO = 0.87f;
    protected static final int HEADING_DEF_BREAK_COLOR_ALPHA = 75;
    private static final float[] HEADING_SIZES = {2.0f, 1.5f, 1.17f, 1.0f, 0.83f, 0.67f};
    protected static final int THEMATIC_BREAK_DEF_ALPHA = 25;
    protected final int blockMargin;
    protected final int blockQuoteColor;
    protected final int blockQuoteWidth;
    protected final int bulletListItemStrokeWidth;
    protected final int bulletWidth;
    protected final int codeBackgroundColor;
    protected final int codeBlockBackgroundColor;
    protected final int codeBlockMargin;
    protected final int codeBlockTextColor;
    protected final int codeBlockTextSize;
    protected final Typeface codeBlockTypeface;
    protected final int codeTextColor;
    protected final int codeTextSize;
    protected final Typeface codeTypeface;
    protected final int headingBreakColor;
    protected final int headingBreakHeight;
    protected final float[] headingTextSizeMultipliers;
    protected final Typeface headingTypeface;
    protected final int linkColor;
    protected final int listItemColor;
    protected final int thematicBreakColor;
    protected final int thematicBreakHeight;

    public static MarkwonTheme create(Context context) {
        return builderWithDefaults(context).build();
    }

    public static Builder emptyBuilder() {
        return new Builder();
    }

    public static Builder builder(MarkwonTheme copyFrom) {
        return new Builder(copyFrom);
    }

    public static Builder builderWithDefaults(Context context) {
        Dip dip = Dip.create(context);
        return new Builder().codeBlockMargin(dip.toPx(8)).blockMargin(dip.toPx(24)).blockQuoteWidth(dip.toPx(4)).bulletListItemStrokeWidth(dip.toPx(1)).headingBreakHeight(dip.toPx(1)).thematicBreakHeight(dip.toPx(4));
    }

    protected MarkwonTheme(Builder builder) {
        this.linkColor = builder.linkColor;
        this.blockMargin = builder.blockMargin;
        this.blockQuoteWidth = builder.blockQuoteWidth;
        this.blockQuoteColor = builder.blockQuoteColor;
        this.listItemColor = builder.listItemColor;
        this.bulletListItemStrokeWidth = builder.bulletListItemStrokeWidth;
        this.bulletWidth = builder.bulletWidth;
        this.codeTextColor = builder.codeTextColor;
        this.codeBlockTextColor = builder.codeBlockTextColor;
        this.codeBackgroundColor = builder.codeBackgroundColor;
        this.codeBlockBackgroundColor = builder.codeBlockBackgroundColor;
        this.codeBlockMargin = builder.codeBlockMargin;
        this.codeTypeface = builder.codeTypeface;
        this.codeBlockTypeface = builder.codeBlockTypeface;
        this.codeTextSize = builder.codeTextSize;
        this.codeBlockTextSize = builder.codeBlockTextSize;
        this.headingBreakHeight = builder.headingBreakHeight;
        this.headingBreakColor = builder.headingBreakColor;
        this.headingTypeface = builder.headingTypeface;
        this.headingTextSizeMultipliers = builder.headingTextSizeMultipliers;
        this.thematicBreakColor = builder.thematicBreakColor;
        this.thematicBreakHeight = builder.thematicBreakHeight;
    }

    public void applyLinkStyle(TextPaint paint) {
        paint.setUnderlineText(true);
        int i = this.linkColor;
        if (i != 0) {
            paint.setColor(i);
        } else {
            paint.setColor(paint.linkColor);
        }
    }

    public void applyLinkStyle(Paint paint) {
        paint.setUnderlineText(true);
        int i = this.linkColor;
        if (i != 0) {
            paint.setColor(i);
        } else if (paint instanceof TextPaint) {
            paint.setColor(((TextPaint) paint).linkColor);
        }
    }

    public void applyBlockQuoteStyle(Paint paint) {
        int color;
        if (this.blockQuoteColor == 0) {
            color = ColorUtils.applyAlpha(paint.getColor(), 25);
        } else {
            color = this.blockQuoteColor;
        }
        paint.setStyle(Paint.Style.FILL);
        paint.setColor(color);
    }

    public int getBlockMargin() {
        return this.blockMargin;
    }

    public int getBlockQuoteWidth() {
        if (this.blockQuoteWidth == 0) {
            return (int) ((((float) this.blockMargin) * 0.25f) + 0.5f);
        }
        return this.blockQuoteWidth;
    }

    public void applyListItemStyle(Paint paint) {
        int color;
        if (this.listItemColor != 0) {
            color = this.listItemColor;
        } else {
            color = paint.getColor();
        }
        paint.setColor(color);
        int i = this.bulletListItemStrokeWidth;
        if (i != 0) {
            paint.setStrokeWidth((float) i);
        }
    }

    public int getBulletWidth(int height) {
        int min = Math.min(this.blockMargin, height) / 2;
        int i = this.bulletWidth;
        if (i == 0 || i > min) {
            return min;
        }
        return this.bulletWidth;
    }

    public void applyCodeTextStyle(Paint paint) {
        int i = this.codeTextColor;
        if (i != 0) {
            paint.setColor(i);
        }
        Typeface typeface = this.codeTypeface;
        if (typeface != null) {
            paint.setTypeface(typeface);
            int i2 = this.codeTextSize;
            if (i2 > 0) {
                paint.setTextSize((float) i2);
                return;
            }
            return;
        }
        paint.setTypeface(Typeface.MONOSPACE);
        int i3 = this.codeTextSize;
        if (i3 > 0) {
            paint.setTextSize((float) i3);
        } else {
            paint.setTextSize(paint.getTextSize() * CODE_DEF_TEXT_SIZE_RATIO);
        }
    }

    public void applyCodeBlockTextStyle(Paint paint) {
        int textColor = this.codeBlockTextColor;
        if (textColor == 0) {
            textColor = this.codeTextColor;
        }
        if (textColor != 0) {
            paint.setColor(textColor);
        }
        Typeface typeface = this.codeBlockTypeface;
        if (typeface == null) {
            typeface = this.codeTypeface;
        }
        if (typeface != null) {
            paint.setTypeface(typeface);
            int textSize = this.codeBlockTextSize;
            if (textSize <= 0) {
                textSize = this.codeTextSize;
            }
            if (textSize > 0) {
                paint.setTextSize((float) textSize);
                return;
            }
            return;
        }
        paint.setTypeface(Typeface.MONOSPACE);
        int textSize2 = this.codeBlockTextSize;
        if (textSize2 <= 0) {
            textSize2 = this.codeTextSize;
        }
        if (textSize2 > 0) {
            paint.setTextSize((float) textSize2);
        } else {
            paint.setTextSize(paint.getTextSize() * CODE_DEF_TEXT_SIZE_RATIO);
        }
    }

    public int getCodeBlockMargin() {
        return this.codeBlockMargin;
    }

    public int getCodeBackgroundColor(Paint paint) {
        if (this.codeBackgroundColor != 0) {
            return this.codeBackgroundColor;
        }
        return ColorUtils.applyAlpha(paint.getColor(), 25);
    }

    public int getCodeBlockBackgroundColor(Paint paint) {
        int color = this.codeBlockBackgroundColor;
        if (color == 0) {
            color = this.codeBackgroundColor;
        }
        if (color != 0) {
            return color;
        }
        return ColorUtils.applyAlpha(paint.getColor(), 25);
    }

    public void applyHeadingTextStyle(Paint paint, int level) {
        Typeface typeface = this.headingTypeface;
        if (typeface == null) {
            paint.setFakeBoldText(true);
        } else {
            paint.setTypeface(typeface);
        }
        float[] textSizes = this.headingTextSizeMultipliers;
        if (textSizes == null) {
            textSizes = HEADING_SIZES;
        }
        if (textSizes == null || textSizes.length < level) {
            throw new IllegalStateException(String.format(Locale.US, "Supplied heading level: %d is invalid, where configured heading sizes are: `%s`", new Object[]{Integer.valueOf(level), Arrays.toString(textSizes)}));
        }
        paint.setTextSize(paint.getTextSize() * textSizes[level - 1]);
    }

    public void applyHeadingBreakStyle(Paint paint) {
        int color;
        if (this.headingBreakColor != 0) {
            color = this.headingBreakColor;
        } else {
            color = ColorUtils.applyAlpha(paint.getColor(), 75);
        }
        paint.setColor(color);
        paint.setStyle(Paint.Style.FILL);
        int i = this.headingBreakHeight;
        if (i >= 0) {
            paint.setStrokeWidth((float) i);
        }
    }

    public void applyThematicBreakStyle(Paint paint) {
        int color;
        if (this.thematicBreakColor != 0) {
            color = this.thematicBreakColor;
        } else {
            color = ColorUtils.applyAlpha(paint.getColor(), 25);
        }
        paint.setColor(color);
        paint.setStyle(Paint.Style.FILL);
        int i = this.thematicBreakHeight;
        if (i >= 0) {
            paint.setStrokeWidth((float) i);
        }
    }

    public static class Builder {
        /* access modifiers changed from: private */
        public int blockMargin;
        /* access modifiers changed from: private */
        public int blockQuoteColor;
        /* access modifiers changed from: private */
        public int blockQuoteWidth;
        /* access modifiers changed from: private */
        public int bulletListItemStrokeWidth;
        /* access modifiers changed from: private */
        public int bulletWidth;
        /* access modifiers changed from: private */
        public int codeBackgroundColor;
        /* access modifiers changed from: private */
        public int codeBlockBackgroundColor;
        /* access modifiers changed from: private */
        public int codeBlockMargin;
        /* access modifiers changed from: private */
        public int codeBlockTextColor;
        /* access modifiers changed from: private */
        public int codeBlockTextSize;
        /* access modifiers changed from: private */
        public Typeface codeBlockTypeface;
        /* access modifiers changed from: private */
        public int codeTextColor;
        /* access modifiers changed from: private */
        public int codeTextSize;
        /* access modifiers changed from: private */
        public Typeface codeTypeface;
        /* access modifiers changed from: private */
        public int headingBreakColor;
        /* access modifiers changed from: private */
        public int headingBreakHeight = -1;
        /* access modifiers changed from: private */
        public float[] headingTextSizeMultipliers;
        /* access modifiers changed from: private */
        public Typeface headingTypeface;
        /* access modifiers changed from: private */
        public int linkColor;
        /* access modifiers changed from: private */
        public int listItemColor;
        /* access modifiers changed from: private */
        public int thematicBreakColor;
        /* access modifiers changed from: private */
        public int thematicBreakHeight = -1;

        Builder() {
        }

        Builder(MarkwonTheme theme) {
            this.linkColor = theme.linkColor;
            this.blockMargin = theme.blockMargin;
            this.blockQuoteWidth = theme.blockQuoteWidth;
            this.blockQuoteColor = theme.blockQuoteColor;
            this.listItemColor = theme.listItemColor;
            this.bulletListItemStrokeWidth = theme.bulletListItemStrokeWidth;
            this.bulletWidth = theme.bulletWidth;
            this.codeTextColor = theme.codeTextColor;
            this.codeBlockTextColor = theme.codeBlockTextColor;
            this.codeBackgroundColor = theme.codeBackgroundColor;
            this.codeBlockBackgroundColor = theme.codeBlockBackgroundColor;
            this.codeBlockMargin = theme.codeBlockMargin;
            this.codeTypeface = theme.codeTypeface;
            this.codeTextSize = theme.codeTextSize;
            this.headingBreakHeight = theme.headingBreakHeight;
            this.headingBreakColor = theme.headingBreakColor;
            this.headingTypeface = theme.headingTypeface;
            this.headingTextSizeMultipliers = theme.headingTextSizeMultipliers;
            this.thematicBreakColor = theme.thematicBreakColor;
            this.thematicBreakHeight = theme.thematicBreakHeight;
        }

        public Builder linkColor(int linkColor2) {
            this.linkColor = linkColor2;
            return this;
        }

        public Builder blockMargin(int blockMargin2) {
            this.blockMargin = blockMargin2;
            return this;
        }

        public Builder blockQuoteWidth(int blockQuoteWidth2) {
            this.blockQuoteWidth = blockQuoteWidth2;
            return this;
        }

        public Builder blockQuoteColor(int blockQuoteColor2) {
            this.blockQuoteColor = blockQuoteColor2;
            return this;
        }

        public Builder listItemColor(int listItemColor2) {
            this.listItemColor = listItemColor2;
            return this;
        }

        public Builder bulletListItemStrokeWidth(int bulletListItemStrokeWidth2) {
            this.bulletListItemStrokeWidth = bulletListItemStrokeWidth2;
            return this;
        }

        public Builder bulletWidth(int bulletWidth2) {
            this.bulletWidth = bulletWidth2;
            return this;
        }

        public Builder codeTextColor(int codeTextColor2) {
            this.codeTextColor = codeTextColor2;
            return this;
        }

        public Builder codeBlockTextColor(int codeBlockTextColor2) {
            this.codeBlockTextColor = codeBlockTextColor2;
            return this;
        }

        public Builder codeBackgroundColor(int codeBackgroundColor2) {
            this.codeBackgroundColor = codeBackgroundColor2;
            return this;
        }

        public Builder codeBlockBackgroundColor(int codeBlockBackgroundColor2) {
            this.codeBlockBackgroundColor = codeBlockBackgroundColor2;
            return this;
        }

        public Builder codeBlockMargin(int codeBlockMargin2) {
            this.codeBlockMargin = codeBlockMargin2;
            return this;
        }

        public Builder codeTypeface(Typeface codeTypeface2) {
            this.codeTypeface = codeTypeface2;
            return this;
        }

        public Builder codeBlockTypeface(Typeface typeface) {
            this.codeBlockTypeface = typeface;
            return this;
        }

        public Builder codeTextSize(int codeTextSize2) {
            this.codeTextSize = codeTextSize2;
            return this;
        }

        public Builder codeBlockTextSize(int codeTextSize2) {
            this.codeBlockTextSize = codeTextSize2;
            return this;
        }

        public Builder headingBreakHeight(int headingBreakHeight2) {
            this.headingBreakHeight = headingBreakHeight2;
            return this;
        }

        public Builder headingBreakColor(int headingBreakColor2) {
            this.headingBreakColor = headingBreakColor2;
            return this;
        }

        public Builder headingTypeface(Typeface headingTypeface2) {
            this.headingTypeface = headingTypeface2;
            return this;
        }

        public Builder headingTextSizeMultipliers(float[] headingTextSizeMultipliers2) {
            this.headingTextSizeMultipliers = headingTextSizeMultipliers2;
            return this;
        }

        public Builder thematicBreakColor(int thematicBreakColor2) {
            this.thematicBreakColor = thematicBreakColor2;
            return this;
        }

        public Builder thematicBreakHeight(int thematicBreakHeight2) {
            this.thematicBreakHeight = thematicBreakHeight2;
            return this;
        }

        public MarkwonTheme build() {
            return new MarkwonTheme(this);
        }
    }
}
