package ru.noties.markwon.html.jsoup.parser;

import java.io.IOException;
import java.io.Reader;
import java.io.StringReader;
import java.util.Arrays;
import java.util.Locale;
import ru.noties.markwon.html.jsoup.UncheckedIOException;
import ru.noties.markwon.html.jsoup.helper.Validate;

public final class CharacterReader {
    static final char EOF = '￿';
    static final int maxBufferLen = 4096;
    private static final int maxStringCacheLen = 12;
    private static final int readAheadLimit = 3072;
    private int bufLength;
    private int bufMark;
    private int bufPos;
    private int bufSplitPoint;
    private final char[] charBuf;
    private final Reader reader;
    private int readerPos;
    private final String[] stringCache;

    public CharacterReader(Reader input, int sz) {
        this.stringCache = new String[128];
        Validate.notNull(input);
        Validate.isTrue(input.markSupported());
        this.reader = input;
        this.charBuf = new char[4096];
        bufferUp();
    }

    public CharacterReader(Reader input) {
        this(input, 4096);
    }

    public CharacterReader(String input) {
        this(new StringReader(input), input.length());
    }

    private void bufferUp() {
        int i = this.bufPos;
        if (i >= this.bufSplitPoint) {
            try {
                this.reader.skip((long) i);
                this.reader.mark(4096);
                int read = this.reader.read(this.charBuf);
                this.reader.reset();
                if (read != -1) {
                    this.bufLength = read;
                    this.readerPos += this.bufPos;
                    this.bufPos = 0;
                    this.bufMark = 0;
                    int i2 = readAheadLimit;
                    if (read <= readAheadLimit) {
                        i2 = read;
                    }
                    this.bufSplitPoint = i2;
                }
            } catch (IOException e) {
                throw new UncheckedIOException(e);
            }
        }
    }

    public int pos() {
        return this.readerPos + this.bufPos;
    }

    public boolean isEmpty() {
        bufferUp();
        return this.bufPos >= this.bufLength;
    }

    private boolean isEmptyNoBufferUp() {
        return this.bufPos >= this.bufLength;
    }

    public char current() {
        bufferUp();
        if (isEmptyNoBufferUp()) {
            return 65535;
        }
        return this.charBuf[this.bufPos];
    }

    /* access modifiers changed from: package-private */
    public char consume() {
        bufferUp();
        char val = isEmptyNoBufferUp() ? 65535 : this.charBuf[this.bufPos];
        this.bufPos++;
        return val;
    }

    /* access modifiers changed from: package-private */
    public void unconsume() {
        this.bufPos--;
    }

    public void advance() {
        this.bufPos++;
    }

    /* access modifiers changed from: package-private */
    public void mark() {
        this.bufMark = this.bufPos;
    }

    /* access modifiers changed from: package-private */
    public void rewindToMark() {
        this.bufPos = this.bufMark;
    }

    /* access modifiers changed from: package-private */
    public int nextIndexOf(char c) {
        bufferUp();
        for (int i = this.bufPos; i < this.bufLength; i++) {
            if (c == this.charBuf[i]) {
                return i - this.bufPos;
            }
        }
        return -1;
    }

    /* access modifiers changed from: package-private */
    public int nextIndexOf(CharSequence seq) {
        bufferUp();
        char startChar = seq.charAt(0);
        int offset = this.bufPos;
        while (offset < this.bufLength) {
            if (startChar != this.charBuf[offset]) {
                do {
                    offset++;
                    if (offset >= this.bufLength) {
                        break;
                    }
                } while (startChar == this.charBuf[offset]);
            }
            int i = offset + 1;
            int last = (seq.length() + i) - 1;
            int i2 = this.bufLength;
            if (offset < i2 && last <= i2) {
                int j = 1;
                while (i < last && seq.charAt(j) == this.charBuf[i]) {
                    i++;
                    j++;
                }
                if (i == last) {
                    return offset - this.bufPos;
                }
            }
            offset++;
        }
        return -1;
    }

    public String consumeTo(char c) {
        int offset = nextIndexOf(c);
        if (offset == -1) {
            return consumeToEnd();
        }
        String consumed = cacheString(this.charBuf, this.stringCache, this.bufPos, offset);
        this.bufPos += offset;
        return consumed;
    }

    /* access modifiers changed from: package-private */
    public String consumeTo(String seq) {
        int offset = nextIndexOf((CharSequence) seq);
        if (offset == -1) {
            return consumeToEnd();
        }
        String consumed = cacheString(this.charBuf, this.stringCache, this.bufPos, offset);
        this.bufPos += offset;
        return consumed;
    }

    public String consumeToAny(char... chars) {
        bufferUp();
        int start = this.bufPos;
        int remaining = this.bufLength;
        char[] val = this.charBuf;
        loop0:
        while (this.bufPos < remaining) {
            for (char c : chars) {
                if (val[this.bufPos] == c) {
                    break loop0;
                }
            }
            this.bufPos++;
        }
        int i = this.bufPos;
        return i > start ? cacheString(this.charBuf, this.stringCache, start, i - start) : "";
    }

    /* access modifiers changed from: package-private */
    public String consumeToAnySorted(char... chars) {
        bufferUp();
        int start = this.bufPos;
        int remaining = this.bufLength;
        char[] val = this.charBuf;
        while (true) {
            int i = this.bufPos;
            if (i >= remaining || Arrays.binarySearch(chars, val[i]) >= 0) {
                int i2 = this.bufPos;
            } else {
                this.bufPos++;
            }
        }
        int i22 = this.bufPos;
        return i22 > start ? cacheString(this.charBuf, this.stringCache, start, i22 - start) : "";
    }

    /* access modifiers changed from: package-private */
    /* JADX WARNING: Removed duplicated region for block: B:10:0x0021  */
    /* JADX WARNING: Removed duplicated region for block: B:11:0x002b A[ORIG_RETURN, RETURN, SYNTHETIC] */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public java.lang.String consumeData() {
        /*
            r6 = this;
            r6.bufferUp()
            int r0 = r6.bufPos
            int r1 = r6.bufLength
            char[] r2 = r6.charBuf
        L_0x0009:
            int r3 = r6.bufPos
            if (r3 >= r1) goto L_0x001f
            char r4 = r2[r3]
            r5 = 38
            if (r4 == r5) goto L_0x001f
            r5 = 60
            if (r4 == r5) goto L_0x001f
            if (r4 != 0) goto L_0x001a
            goto L_0x001f
        L_0x001a:
            int r3 = r3 + 1
            r6.bufPos = r3
            goto L_0x0009
        L_0x001f:
            if (r3 <= r0) goto L_0x002b
            char[] r4 = r6.charBuf
            java.lang.String[] r5 = r6.stringCache
            int r3 = r3 - r0
            java.lang.String r3 = cacheString(r4, r5, r0, r3)
            goto L_0x002d
        L_0x002b:
            java.lang.String r3 = ""
        L_0x002d:
            return r3
        */
        throw new UnsupportedOperationException("Method not decompiled: ru.noties.markwon.html.jsoup.parser.CharacterReader.consumeData():java.lang.String");
    }

    /* access modifiers changed from: package-private */
    /* JADX WARNING: Removed duplicated region for block: B:20:0x0035  */
    /* JADX WARNING: Removed duplicated region for block: B:21:0x003f A[ORIG_RETURN, RETURN, SYNTHETIC] */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public java.lang.String consumeTagName() {
        /*
            r6 = this;
            r6.bufferUp()
            int r0 = r6.bufPos
            int r1 = r6.bufLength
            char[] r2 = r6.charBuf
        L_0x0009:
            int r3 = r6.bufPos
            if (r3 >= r1) goto L_0x0033
            char r4 = r2[r3]
            r5 = 9
            if (r4 == r5) goto L_0x0033
            r5 = 10
            if (r4 == r5) goto L_0x0033
            r5 = 13
            if (r4 == r5) goto L_0x0033
            r5 = 12
            if (r4 == r5) goto L_0x0033
            r5 = 32
            if (r4 == r5) goto L_0x0033
            r5 = 47
            if (r4 == r5) goto L_0x0033
            r5 = 62
            if (r4 == r5) goto L_0x0033
            if (r4 != 0) goto L_0x002e
            goto L_0x0033
        L_0x002e:
            int r3 = r3 + 1
            r6.bufPos = r3
            goto L_0x0009
        L_0x0033:
            if (r3 <= r0) goto L_0x003f
            char[] r4 = r6.charBuf
            java.lang.String[] r5 = r6.stringCache
            int r3 = r3 - r0
            java.lang.String r3 = cacheString(r4, r5, r0, r3)
            goto L_0x0041
        L_0x003f:
            java.lang.String r3 = ""
        L_0x0041:
            return r3
        */
        throw new UnsupportedOperationException("Method not decompiled: ru.noties.markwon.html.jsoup.parser.CharacterReader.consumeTagName():java.lang.String");
    }

    /* access modifiers changed from: package-private */
    public String consumeToEnd() {
        bufferUp();
        char[] cArr = this.charBuf;
        String[] strArr = this.stringCache;
        int i = this.bufPos;
        String data = cacheString(cArr, strArr, i, this.bufLength - i);
        this.bufPos = this.bufLength;
        return data;
    }

    /* access modifiers changed from: package-private */
    public String consumeLetterSequence() {
        char c;
        bufferUp();
        int start = this.bufPos;
        while (true) {
            int i = this.bufPos;
            if (i < this.bufLength && (((c = this.charBuf[i]) >= 'A' && c <= 'Z') || ((c >= 'a' && c <= 'z') || Character.isLetter(c)))) {
                this.bufPos++;
            }
        }
        return cacheString(this.charBuf, this.stringCache, start, this.bufPos - start);
    }

    /* access modifiers changed from: package-private */
    public String consumeLetterThenDigitSequence() {
        char c;
        bufferUp();
        int start = this.bufPos;
        while (true) {
            int i = this.bufPos;
            if (i < this.bufLength && (((c = this.charBuf[i]) >= 'A' && c <= 'Z') || ((c >= 'a' && c <= 'z') || Character.isLetter(c)))) {
                this.bufPos++;
            }
        }
        while (!isEmptyNoBufferUp() && (c = this.charBuf[r2]) >= '0' && c <= '9') {
            this.bufPos = (r2 = this.bufPos) + 1;
        }
        return cacheString(this.charBuf, this.stringCache, start, this.bufPos - start);
    }

    /* access modifiers changed from: package-private */
    public String consumeHexSequence() {
        int i;
        char c;
        bufferUp();
        int start = this.bufPos;
        while (true) {
            i = this.bufPos;
            if (i < this.bufLength && (((c = this.charBuf[i]) >= '0' && c <= '9') || ((c >= 'A' && c <= 'F') || (c >= 'a' && c <= 'f')))) {
                this.bufPos = i + 1;
            }
        }
        return cacheString(this.charBuf, this.stringCache, start, i - start);
    }

    /* access modifiers changed from: package-private */
    public String consumeDigitSequence() {
        int i;
        char c;
        bufferUp();
        int start = this.bufPos;
        while (true) {
            i = this.bufPos;
            if (i < this.bufLength && (c = this.charBuf[i]) >= '0' && c <= '9') {
                this.bufPos = i + 1;
            }
        }
        return cacheString(this.charBuf, this.stringCache, start, i - start);
    }

    /* access modifiers changed from: package-private */
    public boolean matches(char c) {
        return !isEmpty() && this.charBuf[this.bufPos] == c;
    }

    /* access modifiers changed from: package-private */
    public boolean matches(String seq) {
        bufferUp();
        int scanLength = seq.length();
        if (scanLength > this.bufLength - this.bufPos) {
            return false;
        }
        for (int offset = 0; offset < scanLength; offset++) {
            if (seq.charAt(offset) != this.charBuf[this.bufPos + offset]) {
                return false;
            }
        }
        return true;
    }

    /* access modifiers changed from: package-private */
    public boolean matchesIgnoreCase(String seq) {
        bufferUp();
        int scanLength = seq.length();
        if (scanLength > this.bufLength - this.bufPos) {
            return false;
        }
        for (int offset = 0; offset < scanLength; offset++) {
            if (Character.toUpperCase(seq.charAt(offset)) != Character.toUpperCase(this.charBuf[this.bufPos + offset])) {
                return false;
            }
        }
        return true;
    }

    /* access modifiers changed from: package-private */
    public boolean matchesAny(char... seq) {
        if (isEmpty()) {
            return false;
        }
        bufferUp();
        char c = this.charBuf[this.bufPos];
        for (char seek : seq) {
            if (seek == c) {
                return true;
            }
        }
        return false;
    }

    /* access modifiers changed from: package-private */
    public boolean matchesAnySorted(char[] seq) {
        bufferUp();
        return !isEmpty() && Arrays.binarySearch(seq, this.charBuf[this.bufPos]) >= 0;
    }

    /* access modifiers changed from: package-private */
    public boolean matchesLetter() {
        if (isEmpty()) {
            return false;
        }
        char c = this.charBuf[this.bufPos];
        if ((c < 'A' || c > 'Z') && ((c < 'a' || c > 'z') && !Character.isLetter(c))) {
            return false;
        }
        return true;
    }

    /* access modifiers changed from: package-private */
    public boolean matchesDigit() {
        char c;
        if (!isEmpty() && (c = this.charBuf[this.bufPos]) >= '0' && c <= '9') {
            return true;
        }
        return false;
    }

    /* access modifiers changed from: package-private */
    public boolean matchConsume(String seq) {
        bufferUp();
        if (!matches(seq)) {
            return false;
        }
        this.bufPos += seq.length();
        return true;
    }

    /* access modifiers changed from: package-private */
    public boolean matchConsumeIgnoreCase(String seq) {
        if (!matchesIgnoreCase(seq)) {
            return false;
        }
        this.bufPos += seq.length();
        return true;
    }

    /* access modifiers changed from: package-private */
    public boolean containsIgnoreCase(String seq) {
        return nextIndexOf((CharSequence) seq.toLowerCase(Locale.ENGLISH)) > -1 || nextIndexOf((CharSequence) seq.toUpperCase(Locale.ENGLISH)) > -1;
    }

    public String toString() {
        char[] cArr = this.charBuf;
        int i = this.bufPos;
        return new String(cArr, i, this.bufLength - i);
    }

    private static String cacheString(char[] charBuf2, String[] stringCache2, int start, int count) {
        if (count > 12) {
            return new String(charBuf2, start, count);
        }
        if (count < 1) {
            return "";
        }
        int hash = 0;
        int offset = start;
        int i = 0;
        while (i < count) {
            hash = (hash * 31) + charBuf2[offset];
            i++;
            offset++;
        }
        int index = hash & (stringCache2.length - 1);
        String cached = stringCache2[index];
        if (cached == null) {
            String cached2 = new String(charBuf2, start, count);
            stringCache2[index] = cached2;
            return cached2;
        } else if (rangeEquals(charBuf2, start, count, cached)) {
            return cached;
        } else {
            String cached3 = new String(charBuf2, start, count);
            stringCache2[index] = cached3;
            return cached3;
        }
    }

    static boolean rangeEquals(char[] charBuf2, int start, int i, String cached) {
        if (i != cached.length()) {
            return false;
        }
        int i2 = start;
        int j = 0;
        while (true) {
            int count = i - 1;
            if (i == 0) {
                return true;
            }
            int i3 = i2 + 1;
            int j2 = j + 1;
            if (charBuf2[i2] != cached.charAt(j)) {
                return false;
            }
            i2 = i3;
            i = count;
            j = j2;
        }
    }

    /* access modifiers changed from: package-private */
    public boolean rangeEquals(int start, int count, String cached) {
        return rangeEquals(this.charBuf, start, count, cached);
    }
}
