package ru.noties.markwon.html.jsoup.parser;

import ru.noties.markwon.html.jsoup.helper.Normalizer;
import ru.noties.markwon.html.jsoup.helper.Validate;
import ru.noties.markwon.html.jsoup.nodes.Attributes;

public abstract class Token {
    public final TokenType type;

    public enum TokenType {
        Doctype,
        StartTag,
        EndTag,
        Comment,
        Character,
        EOF
    }

    public abstract Token reset();

    protected Token(TokenType tokenType) {
        this.type = tokenType;
    }

    static void reset(StringBuilder sb) {
        if (sb != null) {
            sb.delete(0, sb.length());
        }
    }

    public static final class Doctype extends Token {
        boolean forceQuirks = false;
        final StringBuilder name = new StringBuilder();
        String pubSysKey = null;
        final StringBuilder publicIdentifier = new StringBuilder();
        final StringBuilder systemIdentifier = new StringBuilder();

        Doctype() {
            super(TokenType.Doctype);
        }

        public Token reset() {
            reset(this.name);
            this.pubSysKey = null;
            reset(this.publicIdentifier);
            reset(this.systemIdentifier);
            this.forceQuirks = false;
            return this;
        }

        /* access modifiers changed from: package-private */
        public String getName() {
            return this.name.toString();
        }

        /* access modifiers changed from: package-private */
        public String getPubSysKey() {
            return this.pubSysKey;
        }

        /* access modifiers changed from: package-private */
        public String getPublicIdentifier() {
            return this.publicIdentifier.toString();
        }

        public String getSystemIdentifier() {
            return this.systemIdentifier.toString();
        }

        public boolean isForceQuirks() {
            return this.forceQuirks;
        }
    }

    public static abstract class Tag extends Token {
        public Attributes attributes;
        private boolean hasEmptyAttributeValue = false;
        private boolean hasPendingAttributeValue = false;
        public String normalName;
        private String pendingAttributeName;
        private StringBuilder pendingAttributeValue = new StringBuilder();
        private String pendingAttributeValueS;
        public boolean selfClosing = false;
        public String tagName;

        protected Tag(TokenType tokenType) {
            super(tokenType);
        }

        public Tag reset() {
            this.tagName = null;
            this.normalName = null;
            this.pendingAttributeName = null;
            reset(this.pendingAttributeValue);
            this.pendingAttributeValueS = null;
            this.hasEmptyAttributeValue = false;
            this.hasPendingAttributeValue = false;
            this.selfClosing = false;
            this.attributes = null;
            return this;
        }

        /* access modifiers changed from: package-private */
        public final void newAttribute() {
            String value;
            if (this.attributes == null) {
                this.attributes = new Attributes();
            }
            String str = this.pendingAttributeName;
            if (str != null) {
                String trim = str.trim();
                this.pendingAttributeName = trim;
                if (trim.length() > 0) {
                    if (this.hasPendingAttributeValue) {
                        value = this.pendingAttributeValue.length() > 0 ? this.pendingAttributeValue.toString() : this.pendingAttributeValueS;
                    } else if (this.hasEmptyAttributeValue) {
                        value = "";
                    } else {
                        value = null;
                    }
                    this.attributes.put(this.pendingAttributeName, value);
                }
            }
            this.pendingAttributeName = null;
            this.hasEmptyAttributeValue = false;
            this.hasPendingAttributeValue = false;
            reset(this.pendingAttributeValue);
            this.pendingAttributeValueS = null;
        }

        /* access modifiers changed from: package-private */
        public final void finaliseTag() {
            if (this.pendingAttributeName != null) {
                newAttribute();
            }
        }

        /* access modifiers changed from: package-private */
        public final String name() {
            String str = this.tagName;
            Validate.isFalse(str == null || str.length() == 0);
            return this.tagName;
        }

        /* access modifiers changed from: package-private */
        public final String normalName() {
            return this.normalName;
        }

        /* access modifiers changed from: package-private */
        public final Tag name(String name) {
            this.tagName = name;
            this.normalName = Normalizer.lowerCase(name);
            return this;
        }

        /* access modifiers changed from: package-private */
        public final boolean isSelfClosing() {
            return this.selfClosing;
        }

        /* access modifiers changed from: package-private */
        public final Attributes getAttributes() {
            return this.attributes;
        }

        /* access modifiers changed from: package-private */
        public final void appendTagName(String append) {
            String str = this.tagName;
            String concat = str == null ? append : str.concat(append);
            this.tagName = concat;
            this.normalName = Normalizer.lowerCase(concat);
        }

        /* access modifiers changed from: package-private */
        public final void appendTagName(char append) {
            appendTagName(String.valueOf(append));
        }

        /* access modifiers changed from: package-private */
        public final void appendAttributeName(String append) {
            String str = this.pendingAttributeName;
            this.pendingAttributeName = str == null ? append : str.concat(append);
        }

        /* access modifiers changed from: package-private */
        public final void appendAttributeName(char append) {
            appendAttributeName(String.valueOf(append));
        }

        /* access modifiers changed from: package-private */
        public final void appendAttributeValue(String append) {
            ensureAttributeValue();
            if (this.pendingAttributeValue.length() == 0) {
                this.pendingAttributeValueS = append;
            } else {
                this.pendingAttributeValue.append(append);
            }
        }

        /* access modifiers changed from: package-private */
        public final void appendAttributeValue(char append) {
            ensureAttributeValue();
            this.pendingAttributeValue.append(append);
        }

        /* access modifiers changed from: package-private */
        public final void appendAttributeValue(char[] append) {
            ensureAttributeValue();
            this.pendingAttributeValue.append(append);
        }

        /* access modifiers changed from: package-private */
        public final void appendAttributeValue(int[] appendCodepoints) {
            ensureAttributeValue();
            for (int codepoint : appendCodepoints) {
                this.pendingAttributeValue.appendCodePoint(codepoint);
            }
        }

        /* access modifiers changed from: package-private */
        public final void setEmptyAttributeValue() {
            this.hasEmptyAttributeValue = true;
        }

        private void ensureAttributeValue() {
            this.hasPendingAttributeValue = true;
            String str = this.pendingAttributeValueS;
            if (str != null) {
                this.pendingAttributeValue.append(str);
                this.pendingAttributeValueS = null;
            }
        }
    }

    public static final class StartTag extends Tag {
        public StartTag() {
            super(TokenType.StartTag);
            this.attributes = new Attributes();
        }

        public Tag reset() {
            super.reset();
            this.attributes = new Attributes();
            return this;
        }

        /* access modifiers changed from: package-private */
        public StartTag nameAttr(String name, Attributes attributes) {
            this.tagName = name;
            this.attributes = attributes;
            this.normalName = Normalizer.lowerCase(this.tagName);
            return this;
        }

        public String toString() {
            if (this.attributes == null || this.attributes.size() <= 0) {
                return "<" + name() + ">";
            }
            return "<" + name() + " " + this.attributes.toString() + ">";
        }
    }

    public static final class EndTag extends Tag {
        EndTag() {
            super(TokenType.EndTag);
        }

        public String toString() {
            return "</" + name() + ">";
        }
    }

    public static final class Comment extends Token {
        boolean bogus = false;
        final StringBuilder data = new StringBuilder();

        public Token reset() {
            reset(this.data);
            this.bogus = false;
            return this;
        }

        Comment() {
            super(TokenType.Comment);
        }

        /* access modifiers changed from: package-private */
        public String getData() {
            return this.data.toString();
        }

        public String toString() {
            return "<!--" + getData() + "-->";
        }
    }

    public static class Character extends Token {
        private String data;

        Character() {
            super(TokenType.Character);
        }

        public Token reset() {
            this.data = null;
            return this;
        }

        /* access modifiers changed from: package-private */
        public Character data(String data2) {
            this.data = data2;
            return this;
        }

        public String getData() {
            return this.data;
        }

        public String toString() {
            return getData();
        }
    }

    public static final class CData extends Character {
        CData(String data) {
            data(data);
        }

        public String toString() {
            return "<![CDATA[" + getData() + "]]>";
        }
    }

    public static final class EOF extends Token {
        EOF() {
            super(TokenType.EOF);
        }

        public Token reset() {
            return this;
        }
    }
}
